<?php
/*
 * Plugin Name: Options for Twenty Twenty-One Premium
 * Version: 1.4.7
 * Plugin URI: https://webd.uk/product/options-for-twenty-twenty-one-upgrade/
 * Description: Adds even more options to modify the default Wordpress theme Twenty Twenty-One
 * Author: Webd Ltd
 * Author URI: https://webd.uk
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('options_for_twenty_twenty_one_premium_class')) {

	class options_for_twenty_twenty_one_premium_class {

        public static $version = '1.4.7';

		function __construct() {

            add_action('customize_register', array($this, 'oftto_customize_register'), 999);
            add_action('widgets_init', array($this, 'oftto_widgets_init'), 11);
            add_action('init', array($this, 'oftto_archive_featured_images'));

            if (is_admin()) {

                add_action('load-post.php', array($this, 'oftto_theme_options_metabox_setup'));
                add_action('load-post-new.php', array($this, 'oftto_theme_options_metabox_setup'));

                add_filter('pre_set_site_transient_update_plugins', 'ofttoPremium::check_plugin_update');
                add_filter('plugins_api', 'ofttoPremium::get_plugin_information', 10, 3);
                add_filter('after_plugin_row_' . plugin_basename(__FILE__), 'ofttoPremium::activate_purchase_js', 10, 3);
                add_action('wp_ajax_oftto_activate_purchase', 'ofttoPremium::activate_purchase');
                add_action('admin_notices', 'ofttoPremium::upgrade_notice');
                add_filter('upgrader_pre_download', 'ofttoPremium::upgrader_pre_download', 10, 3);
                add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'oftto_add_plugin_action_links'));
                add_filter('plugin_row_meta', 'ofttoPremium::plugin_row_meta', 10, 4);

            } else {

                add_filter('twenty_twenty_one_svg_icons_ui', array($this, 'oftto_inject_ui_icons'));
                add_filter('twenty_twenty_one_svg_icons_social', array($this, 'oftto_extract_social_icons'), 999);
                add_filter('twenty_twenty_one_social_icons_map', array($this, 'oftto_extract_social_icons_map'), 999);
                add_filter('walker_nav_menu_start_el', array($this, 'oftto_nav_menu_social_icons_class_inject'), 999, 4);

                add_action('wp_head' , array($this, 'oftto_header_output'));
                add_action('wp_footer', array($this, 'oftto_frontend_javascript'), 11);

            }

            if (get_theme_mod('sticky_nav_on_mobile')) {

                set_theme_mod('sticky_mobile', 'site-navigation');
                remove_theme_mod('sticky_nav_on_mobile');

            }

            if (get_theme_mod('sticky_nav_on_desktop')) {

                set_theme_mod('sticky_desktop', 'site-navigation');
                remove_theme_mod('sticky_nav_on_desktop');

            }

            if (true === get_theme_mod('inline_logo')) {

                set_theme_mod('inline_logo', 'desktop');

            }

		}

    	protected static $social_icons;

    	protected static $social_icons_map;

    	protected static $social_icons_regex_map;

		function oftto_add_plugin_action_links($links) {

			$settings_links = ofttoCommon::plugin_action_links(admin_url('customize.php'), true);

			return array_merge($settings_links, $links);

		}

        function oftto_customize_register($wp_customize) {

            if (!class_exists('reset_customizer_class')) {

                $wp_customize->add_section('reset_customizer', array(
                    'title'     => __('Backup Customizer', 'reset-customizer'),
                    'description'  => __('Reset Customizer plugin allows you to backup and restore your customizer settings. You can also reset the options within each section of the customizer to their defaults without affecting other settings.', 'options-for-twenty-twenty-one'),
                    'priority'     => 0
                ));

                ofttoCommon::add_hidden_control($wp_customize, 'install_reset_customizer', 'reset_customizer', '', sprintf(wp_kses(__('<a href="%s" class="button-primary">Install Reset Customizer plugin</a>.', 'options-for-twenty-twenty-one'), array('a' => array('href' => array(), 'class' => array()))), esc_url(wp_nonce_url(add_query_arg(array('action' => 'install-plugin', 'plugin' => 'reset-customizer'), self_admin_url('update.php')), 'install-plugin_reset-customizer'))));

            }



            $upgrade_link = '<a href="' . ofttoCommon::upgrade_link() . '" title="' . __('Upgrade to Options for Twenty Twenty-One Premium', 'options-for-twenty-twenty-one') . '">' . __('Upgrade to Options for Twenty Twenty-One Premium', 'options-for-twenty-twenty-one') . '</a>';
            $upgrade_nag = $upgrade_link . __(' to activate this option.', 'options-for-twenty-twenty-one');



            $control_label = __('Featured Background Image', 'options-for-twenty-twenty-one');
            $control_description = __('Use the featured image as the background image (where applicable).', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('featured_background_image', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('featured_background_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_general',
                'settings'      => 'featured_background_image',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'featured_background_image', 'oftto_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Left Sidebar', 'options-for-twenty-twenty-one');
            $control_description = __('Align the sidebar to the left on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('left_sidebar', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('left_sidebar', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_general',
                'settings'      => 'left_sidebar',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'left_sidebar', 'oftto_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Width', 'options-for-twenty-twenty-one');
            $control_description = __('Set the width of the injected sidebar.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('sidebar_width', array(
                'default'           => 33,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('sidebar_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_general',
                'settings'      => 'sidebar_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 10,
                    'max'   => 80,
                    'step'  => 1
                ),
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'sidebar_width', 'oftto_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Min Width', 'options-for-twenty-twenty-one');
            $control_description = __('Set the minimum width of the injected sidebar. This will prevent the sidebar from being too narrow on smaller screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('sidebar_min_width', array(
                'default'           => 0,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('sidebar_min_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_general',
                'settings'      => 'sidebar_min_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 0,
                    'max'   => 500,
                    'step'  => 10
                ),
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'sidebar_min_width', 'oftto_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Archive Row Template', 'options-for-twenty-twenty-one');
            $control_description = __('Show posts in a row format on taxonomy pages.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $taxonomies = array(
                'blog' => 'Posts / Blog Page',
                'search' => 'Search Page'
            );

            foreach(get_taxonomies(array('public' => 'true'), 'objects') as $taxonomy) {

                $taxonomies[$taxonomy->name] = __('Taxonomy: ', 'options-for-twenty-twenty-one') . ': ' . $taxonomy->label;

            }

            unset($taxonomies['post_format']);
            $grid_taxonomies = get_theme_mod('archive_grid_template');

            if ($grid_taxonomies && is_array($grid_taxonomies)) {

                foreach ($grid_taxonomies as $grid_taxonomy) {

                    if (isset($taxonomies[$grid_taxonomy])) { unset($taxonomies[$grid_taxonomy]); }

                }

            }

            $column_taxonomies = get_theme_mod('archive_column_template');

            if ($column_taxonomies && is_array($column_taxonomies)) {

                foreach ($column_taxonomies as $column_taxonomy) {

                    if (isset($taxonomies[$column_taxonomy])) { unset($taxonomies[$column_taxonomy]); }

                }

            }

            $card_taxonomies = get_theme_mod('archive_card_template');

            if ($card_taxonomies && is_array($card_taxonomies)) {

                foreach ($card_taxonomies as $card_taxonomy) {

                    if (isset($taxonomies[$card_taxonomy])) { unset($taxonomies[$card_taxonomy]); }

                }

            }

            $wp_customize->add_setting('archive_row_template', array(
                'default'       => array(),
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_multiple_options'
            ));
            $wp_customize->add_control(new webd_Customize_Control_Checkbox_Multiple($wp_customize, 'archive_row_template', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_general',
                'settings'      => 'archive_row_template',
                'choices'       => $taxonomies
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'archive_row_template', 'oftto_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Archive Column Template', 'options-for-twenty-twenty-one');
            $control_description = __('Show posts in a column format on taxonomy pages.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $taxonomies = array(
                'blog' => 'Posts / Blog Page',
                'search' => 'Search Page'
            );

            foreach(get_taxonomies(array('public' => 'true'), 'objects') as $taxonomy) {

                $taxonomies[$taxonomy->name] = __('Taxonomy: ', 'options-for-twenty-twenty-one') . ': ' . $taxonomy->label;

            }

            unset($taxonomies['post_format']);
            $grid_taxonomies = get_theme_mod('archive_grid_template');

            if ($grid_taxonomies && is_array($grid_taxonomies)) {

                foreach ($grid_taxonomies as $grid_taxonomy) {

                    if (isset($taxonomies[$grid_taxonomy])) { unset($taxonomies[$grid_taxonomy]); }

                }

            }

            $row_taxonomies = get_theme_mod('archive_row_template');

            if ($row_taxonomies && is_array($row_taxonomies)) {

                foreach ($row_taxonomies as $row_taxonomy) {

                    if (isset($taxonomies[$row_taxonomy])) { unset($taxonomies[$row_taxonomy]); }

                }

            }

            $card_taxonomies = get_theme_mod('archive_card_template');

            if ($card_taxonomies && is_array($card_taxonomies)) {

                foreach ($card_taxonomies as $card_taxonomy) {

                    if (isset($taxonomies[$card_taxonomy])) { unset($taxonomies[$card_taxonomy]); }

                }

            }

            $wp_customize->add_setting('archive_column_template', array(
                'default'       => array(),
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_multiple_options'
            ));
            $wp_customize->add_control(new webd_Customize_Control_Checkbox_Multiple($wp_customize, 'archive_column_template', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_general',
                'settings'      => 'archive_column_template',
                'choices'       => $taxonomies
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'archive_column_template', 'oftto_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Archive Card Template', 'options-for-twenty-twenty-one');
            $control_description = __('Show posts in a card format on taxonomy pages.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $taxonomies = array(
                'blog' => 'Posts / Blog Page',
                'search' => 'Search Page'
            );

            foreach(get_taxonomies(array('public' => 'true'), 'objects') as $taxonomy) {

                $taxonomies[$taxonomy->name] = __('Taxonomy: ', 'options-for-twenty-twenty-one') . ': ' . $taxonomy->label;

            }

            unset($taxonomies['post_format']);
            $grid_taxonomies = get_theme_mod('archive_grid_template');

            if ($grid_taxonomies && is_array($grid_taxonomies)) {

                foreach ($grid_taxonomies as $grid_taxonomy) {

                    if (isset($taxonomies[$grid_taxonomy])) { unset($taxonomies[$grid_taxonomy]); }

                }

            }

            $row_taxonomies = get_theme_mod('archive_row_template');

            if ($row_taxonomies && is_array($row_taxonomies)) {

                foreach ($row_taxonomies as $row_taxonomy) {

                    if (isset($taxonomies[$row_taxonomy])) { unset($taxonomies[$row_taxonomy]); }

                }

            }

            $column_taxonomies = get_theme_mod('archive_column_template');

            if ($column_taxonomies && is_array($column_taxonomies)) {

                foreach ($column_taxonomies as $column_taxonomy) {

                    if (isset($taxonomies[$column_taxonomy])) { unset($taxonomies[$column_taxonomy]); }

                }

            }

            $wp_customize->add_setting('archive_card_template', array(
                'default'       => array(),
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_multiple_options'
            ));
            $wp_customize->add_control(new webd_Customize_Control_Checkbox_Multiple($wp_customize, 'archive_card_template', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_general',
                'settings'      => 'archive_card_template',
                'choices'       => $taxonomies
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'archive_card_template', 'oftto_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Mobile', 'options-for-twenty-twenty-one');
            $control_description = __('Fix the header, navigation bar or floating hamburger to the top of the screen on small screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_mobile', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('sticky_mobile', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'sticky_mobile',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Disabled (Default)', 'options-for-twenty-twenty-one'),
                    'masthead-wrapper' => __('Sticky Header', 'options-for-twenty-twenty-one'),
                    'site-navigation' => __('Sticky Nav Bar', 'options-for-twenty-twenty-one'),
                    'button' => __('Sticky Hamburger', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'sticky_mobile', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Desktop', 'options-for-twenty-twenty-one');
            $control_description = __('Fix the header, navigation bar or floating hamburger to the top of the screen on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_desktop', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('sticky_desktop', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'sticky_desktop',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Disabled (Default)', 'options-for-twenty-twenty-one'),
                    'masthead-wrapper' => __('Sticky Header', 'options-for-twenty-twenty-one'),
                    'site-navigation' => __('Sticky Nav Bar', 'options-for-twenty-twenty-one'),
                    'button' => __('Sticky Hamburger', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'sticky_desktop', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Dropshadow', 'options-for-twenty-twenty-one');
            $control_description = __('Add a dropshadow to the sticky headers and menus.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_menu_dropshadow', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('sticky_menu_dropshadow', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'sticky_menu_dropshadow',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'sticky_menu_dropshadow', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Animate Dropshadow', 'options-for-twenty-twenty-one');
            $control_description = __('Give a 3D animation to the dropshadow on sticky headers and menus.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_menu_shadow_animate', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('sticky_menu_shadow_animate', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'sticky_menu_shadow_animate',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'sticky_menu_shadow_animate', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Featured Header Image', 'options-for-twenty-twenty-one');
            $control_description = __('Use the featured image as the header image (where applicable).', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('featured_header_image', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('featured_header_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'featured_header_image',
                'type'          => 'checkbox',
                'active_callback' => 'options_for_twenty_twenty_one_premium_class::oftto_has_masthead_wrapper'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'featured_header_image', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Header Gradient Height', 'options-for-twenty-twenty-one');
            $control_description = __('Change the height of the header gradient.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('header_gradient_height', array(
                'default'           => 0,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('header_gradient_height', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'header_gradient_height',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 0,
                    'max'   => 100,
                    'step'  => 1
                ),
                'active_callback' => 'options_for_twenty_twenty_one_premium_class::oftto_has_masthead_wrapper'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'header_gradient_height', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Header Gradient Color', 'options-for-twenty-twenty-one');
            $control_description = __('Change the color header gradient.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('header_gradient_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'header_gradient_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
            	'settings'      => 'header_gradient_color',
                'active_callback' => 'options_for_twenty_twenty_one_premium_class::oftto_has_masthead_wrapper'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'header_gradient_color', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Header Gradient Opacity', 'options-for-twenty-twenty-one');
            $control_description = __('Change the opacity of the header gradient.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('header_gradient_opacity', array(
                'default'           => 30,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('header_gradient_opacity', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'header_gradient_opacity',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 100,
                    'step'  => 1
                ),
                'active_callback' => 'options_for_twenty_twenty_one_premium_class::oftto_has_masthead_wrapper'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'header_gradient_opacity', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Header Widget Area Position', 'options-for-twenty-twenty-one');
            $control_description = __('Place the Header Widget Area at the top or the bottom of the header.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('header_widget_area', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('header_widget_area', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'header_widget_area',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Top (Default)', 'options-for-twenty-twenty-one'),
                    'bottom' => __('Bottom', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'header_widget_area', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Inline Logo', 'options-for-twenty-twenty-one');
            $control_description = __('Move logo inline with site title and description.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('inline_logo', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('inline_logo', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'inline_logo',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Off', 'options-for-twenty-twenty-one'),
                    'on' => __('On', 'options-for-twenty-twenty-one'),
                    'desktop' => __('Only Desktop', 'options-for-twenty-twenty-one'),
                    'mobile' => __('Only Mobile', 'options-for-twenty-twenty-one')
                ),
                'active_callback' => 'options_for_twenty_twenty_one_class::oftto_are_title_and_tagline_displayed'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'inline_logo', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Text Shadow Width', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the width of the shadow on text in the header.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('header_text_shadow_width', array(
                'default'       => 0,
                'transport'     => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('header_text_shadow_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
                'settings'      => 'header_text_shadow_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 0,
                    'max'   => 11,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'header_text_shadow_width', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Text Shadow Color', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the color of the shadow on text in the header.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('header_text_shadow_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'header_text_shadow_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_header',
            	'settings'      => 'header_text_shadow_color'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'header_text_shadow_color', 'oftto_header', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Desktop Nav on Mobile', 'options-for-twenty-twenty-one');
            $control_description = __('Show the desktop navigation on smaller screen sizes.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('desktop_nav_on_mobile', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('desktop_nav_on_mobile', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'desktop_nav_on_mobile',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'desktop_nav_on_mobile', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Mobile Nav Breakpoint', 'options-for-twenty-twenty-one');
            $control_description = __('Choose when to show the mobile navigation hamburger menu on larger screen sizes.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('mobile_nav_breakpoint', array(
                'default'       => 0,
                'transport'     => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('mobile_nav_breakpoint', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'mobile_nav_breakpoint',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 0,
                    'max'   => 959,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'mobile_nav_breakpoint', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Mobile Nav Flyout', 'options-for-twenty-twenty-one');
            $control_description = __('Show the hamburger navigation as a flyout on larger screens if enabled with "Sticky Desktop", "Mobile Nav on Desktop" or "Mobile Nav Breakpoint" options.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('mobile_nav_flyout', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('mobile_nav_flyout', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'mobile_nav_flyout',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'mobile_nav_flyout', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Menu Item Border Width', 'options-for-twenty-twenty-one');
            $control_description = __('Add a border to the primary navigation menu items on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('nav_border_width', array(
                'default'           => 0,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('nav_border_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'nav_border_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 0,
                    'max'   => 10,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'nav_border_width', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Menu Item Border Color', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the border color on the primary navigation menu items on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('nav_border_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'nav_border_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
            	'settings'      => 'nav_border_color'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'nav_border_color', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Menu Item Border Style', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the border style on the primary navigation menu items on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('nav_border_style', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('nav_border_style', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'nav_border_style',
                'type'          => 'select',
                'choices'       => array(
                    'dotted' => __('Dotted', 'options-for-twenty-twenty-one'),
                    'dashed' => __('Dashed', 'options-for-twenty-twenty-one'),
                    '' => __('Solid (Default)', 'options-for-twenty-twenty-one'),
                    'double' => __('Double', 'options-for-twenty-twenty-one'),
                    'groove' => __('3D Groove', 'options-for-twenty-twenty-one'),
                    'ridge' => __('3D Ridge', 'options-for-twenty-twenty-one'),
                    'inset' => __('3D Inset', 'options-for-twenty-twenty-one'),
                    'outset' => __('3D Outset', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'nav_border_style', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Menu Item Background Color', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the background color on the primary navigation menu items on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('nav_item_background_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'nav_item_background_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
            	'settings'      => 'nav_item_background_color'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'nav_item_background_color', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Menu Item Border Radius', 'options-for-twenty-twenty-one');
            $control_description = __('Add border radius to the primary navigation menu items on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('nav_item_border_radius', array(
                'default'           => 0,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('nav_item_border_radius', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'nav_item_border_radius',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 0,
                    'max'   => 3125,
                    'step'  => 25
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'nav_item_border_radius', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Menu Item Margin', 'options-for-twenty-twenty-one');
            $control_description = __('Increase the margin on the primary navigation menu items on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('nav_item_margin', array(
                'default'           => 0,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('nav_item_margin', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'nav_item_margin',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 0,
                    'max'   => 20,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'nav_item_margin', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Hide Submenu Toggle', 'options-for-twenty-twenty-one');
            $control_description = __('Hides the switch that opens and closes submenus on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('hide_submenu_toggle', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('hide_submenu_toggle', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'hide_submenu_toggle',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'hide_submenu_toggle', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Second-Level Sub-Menus', 'options-for-twenty-twenty-one');
            $control_description = __('Enables second-level, flyout sub-menus on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('second_level_submenus', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('second_level_submenus', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'second_level_submenus',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'second_level_submenus', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Second-Level Sub-Menu Background Color', 'options-for-twenty-twenty-one');
            $control_description = __('Change the color of the second-level sub-menu backgrounds on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('second_submenu_background_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'second_submenu_background_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
            	'settings'      => 'second_submenu_background_color'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'second_submenu_background_color', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Mobile Sub-Menus', 'options-for-twenty-twenty-one');
            $control_description = __('Enables sub-menus for smaller screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('mobile_submenus', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('mobile_submenus', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'mobile_submenus',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'mobile_submenus', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Primary Nav Search', 'options-for-twenty-twenty-one');
            $control_description = __('Add a search facility to the primary navigation.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('primary_nav_search', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('primary_nav_search', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_navigation',
                'settings'      => 'primary_nav_search',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'primary_nav_search', 'oftto_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Content Background Color', 'options-for-twenty-twenty-one');
            $control_description = __('Wrap the page / post content so it can have a different background color.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('content_background_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'content_background_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
            	'settings'      => 'content_background_color'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'content_background_color', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Remove Archive Title Prefix', 'options-for-twenty-twenty-one');
            $control_description = __('Remove the word "Tag" or "Category" in archive titles.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('remove_archive_title_prefix', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('remove_archive_title_prefix', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'remove_archive_title_prefix',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'remove_archive_title_prefix', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Parallax Cover Block', 'options-for-twenty-twenty-one');
            $control_description = __('Turn on a parallax effect for the cover block.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('parallax_cover_block', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('parallax_cover_block', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'parallax_cover_block',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'parallax_cover_block', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Archive Featured Images', 'options-for-twenty-twenty-one');
            $control_description = __('Add featured image functionality to category and tag pages.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $taxonomies = array();

            foreach(get_taxonomies(array('public' => 'true'), 'objects') as $taxonomy) {

                $taxonomies[$taxonomy->name] = __('Taxonomy: ', 'options-for-twenty-twenty-one') . ': ' . $taxonomy->label;

            }

            unset($taxonomies['post_format']);

            $wp_customize->add_setting('archive_featured_images', array(
                'default'       => array(),
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_multiple_options'
            ));
            $wp_customize->add_control(new webd_Customize_Control_Checkbox_Multiple($wp_customize, 'archive_featured_images', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'archive_featured_images',
                'choices'       => $taxonomies
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'archive_featured_images', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Template Columns (Small Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Select the number of columns per row in the grid template on small screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('grid_columns_small', array(
                'default'       => '1',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('grid_columns_small', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_columns_small',
                'type'          => 'select',
                'choices'       => array(
                    '1' => __('1 Column', 'options-for-twenty-twenty-one'),
                    '2' => __('2 Columns', 'options-for-twenty-twenty-one'),
                    '3' => __('3 Columns', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_columns_small', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Template Columns (Medium Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Select the number of columns per row in the grid template on medium screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('grid_columns_medium', array(
                'default'       => '4',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('grid_columns_medium', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_columns_medium',
                'type'          => 'select',
                'choices'       => array(
                    '2' => __('2 Columns', 'options-for-twenty-twenty-one'),
                    '3' => __('3 Columns', 'options-for-twenty-twenty-one'),
                    '4' => __('4 Columns', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_columns_medium', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Template Columns (Large Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Select the number of columns per row in the grid template on large screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('grid_columns_large', array(
                'default'       => '4',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('grid_columns_large', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_columns_large',
                'type'          => 'select',
                'choices'       => array(
                    '2' => __('2 Columns', 'options-for-twenty-twenty-one'),
                    '3' => __('3 Columns', 'options-for-twenty-twenty-one'),
                    '4' => __('4 Columns', 'options-for-twenty-twenty-one'),
                    '5' => __('5 Columns', 'options-for-twenty-twenty-one'),
                    '6' => __('6 Columns', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_columns_large', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Column Template Columns (Small Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Select the number of columns per row in the column template on small screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('column_columns_small', array(
                'default'       => '1',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('column_columns_small', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'column_columns_small',
                'type'          => 'select',
                'choices'       => array(
                    '1' => __('1 Column', 'options-for-twenty-twenty-one'),
                    '2' => __('2 Columns', 'options-for-twenty-twenty-one'),
                    '3' => __('3 Columns', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'column_columns_small', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Column Template Columns (Medium Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Select the number of columns per row in the column template on medium screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('column_columns_medium', array(
                'default'       => '2',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('column_columns_medium', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'column_columns_medium',
                'type'          => 'select',
                'choices'       => array(
                    '2' => __('2 Columns', 'options-for-twenty-twenty-one'),
                    '3' => __('3 Columns', 'options-for-twenty-twenty-one'),
                    '4' => __('4 Columns', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'column_columns_medium', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Column Template Columns (Large Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Select the number of columns per row in the column template on large screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('column_columns_large', array(
                'default'       => '3',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('column_columns_large', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'column_columns_large',
                'type'          => 'select',
                'choices'       => array(
                    '2' => __('2 Columns', 'options-for-twenty-twenty-one'),
                    '3' => __('3 Columns', 'options-for-twenty-twenty-one'),
                    '4' => __('4 Columns', 'options-for-twenty-twenty-one'),
                    '5' => __('5 Columns', 'options-for-twenty-twenty-one'),
                    '6' => __('6 Columns', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'column_columns_large', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Box Shape', 'options-for-twenty-twenty-one');
            $control_description = __('Adjust the aspect ratio of the posts in the grid template.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('grid_box_shape', array(
                'default'       => 65,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('grid_box_shape', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_box_shape',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 25,
                    'max'   => 100,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_box_shape', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Border Width', 'options-for-twenty-twenty-one');
            $control_description = __('Adjust the width of the border around posts in the grid template that don\'t have a featured image.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('grid_border_width', array(
                'default'           => 2,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('grid_border_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_border_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 11,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_border_width', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Border Color', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the color of the border around posts in the grid template that don\'t have a featured image.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('grid_border_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'grid_border_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
            	'settings'      => 'grid_border_color'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_border_color', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Border Style', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the style of the border around posts in the grid template that don\'t have a featured image.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('grid_border_style', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('grid_border_style', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_border_style',
                'type'          => 'select',
                'choices'       => array(
                    'dotted' => __('Dotted', 'options-for-twenty-twenty-one'),
                    'dashed' => __('Dashed', 'options-for-twenty-twenty-one'),
                    '' => __('Solid (Default)', 'options-for-twenty-twenty-one'),
                    'double' => __('Double', 'options-for-twenty-twenty-one'),
                    'groove' => __('3D Groove', 'options-for-twenty-twenty-one'),
                    'ridge' => __('3D Ridge', 'options-for-twenty-twenty-one'),
                    'inset' => __('3D Inset', 'options-for-twenty-twenty-one'),
                    'outset' => __('3D Outset', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_border_style', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Font Size (Small Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Adjust the title font size in the grid template on small screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('grid_font_size_small', array(
                'default'       => 80,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('grid_font_size_small', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_font_size_small',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 40,
                    'max'   => 160,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_font_size_small', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Font Size (Medium Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Adjust the title font size in the grid template on medium screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('grid_font_size_medium', array(
                'default'       => 40,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('grid_font_size_medium', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_font_size_medium',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 20,
                    'max'   => 80,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_font_size_medium', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Font Size (Large Screen)', 'options-for-twenty-twenty-one');
            $control_description = __('Adjust the title font size in the grid template on large screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('grid_font_size_large', array(
                'default'       => 20,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('grid_font_size_large', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_font_size_large',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 10,
                    'max'   => 40,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_font_size_large', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Title Shadow Width', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the width of the shadow on the title in the grid template.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('grid_title_shadow_width', array(
                'default'       => 2,
                'transport'     => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('grid_title_shadow_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_title_shadow_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 12,
                    'step'  => 1
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_title_shadow_width', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Title Shadow Color', 'options-for-twenty-twenty-one');
            $control_description = __('Choose the color of the shadow on the title in the grid template.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('grid_title_shadow_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'grid_title_shadow_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
            	'settings'      => 'grid_title_shadow_color'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_title_shadow_color', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Title Font Case', 'options-for-twenty-twenty-one');
            $control_description = __('Change the font case of the grid title.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('grid_title_text_transform', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('grid_title_text_transform', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_title_text_transform',
                'type'          => 'select',
                'choices'       => array(
                    'none' => __('None', 'options-for-twenty-twenty-one'),
                    'capitalize' => __('Capitalise', 'options-for-twenty-twenty-one'),
                    '' => __('Uppercase', 'options-for-twenty-twenty-one'),
                    'lowercase' => __('Lowercase', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_title_text_transform', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Grid Hover Animation', 'options-for-twenty-twenty-one');
            $control_description = __('Show an animated hover effect on grid items.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('grid_hover_animation', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('grid_hover_animation', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_hover_animation',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_hover_animation', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Show Post Dates in Grid Template', 'options-for-twenty-twenty-one');
            $control_description = __('Show published dates on the grid template.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('grid_post_dates', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('grid_post_dates', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'grid_post_dates',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'grid_post_dates', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Show Post Dates in Column Template', 'options-for-twenty-twenty-one');
            $control_description = __('Show published dates on the column template.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('column_post_dates', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('column_post_dates', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'column_post_dates',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'column_post_dates', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Show Updated Date', 'options-for-twenty-twenty-one');
            $control_description = __('Show "updated" date rather than "published" date. This option will only show once you have published changes because to work it has to override a theme function before the Customizer is loaded.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('show_updated_date', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('show_updated_date', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'show_updated_date',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'show_updated_date', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Remove "Published" Text', 'options-for-twenty-twenty-one');
            $control_description = __('Remove the word "Published" before the date on posts and words "Published in" on attachment pages.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('remove_published_text', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('remove_published_text', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_content',
                'settings'      => 'remove_published_text',
                'type'          => 'checkbox'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'remove_published_text', 'oftto_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Widget Area Background Color', 'options-for-twenty-twenty-one');
            $control_description = __('Change the color behind the footer widget area.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('footer_widget_area_background_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'footer_widget_area_background_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_footer',
            	'settings'      => 'footer_widget_area_background_color'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'footer_widget_area_background_color', 'oftto_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Fix Social Links for Desktop', 'options-for-twenty-twenty-one');
            $control_description = __('Fix the social links to the left or right for large screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('fix_social_links', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('fix_social_links', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_footer',
                'settings'      => 'fix_social_links',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Do not fix', 'options-for-twenty-twenty-one'),
                    'left' => __('Fix to the left', 'options-for-twenty-twenty-one'),
                    'right' => __('Fix to the right', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'fix_social_links', 'oftto_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Fix Social Links for Mobile', 'options-for-twenty-twenty-one');
            $control_description = __('Fix the social links to the left or right for small screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission()) {

            $wp_customize->add_setting('fix_social_links_mobile', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_options'
            ));
            $wp_customize->add_control('fix_social_links_mobile', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_footer',
                'settings'      => 'fix_social_links_mobile',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Do not fix', 'options-for-twenty-twenty-one'),
                    'left' => __('Fix to the left', 'options-for-twenty-twenty-one'),
                    'right' => __('Fix to the right', 'options-for-twenty-twenty-one')
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'fix_social_links_mobile', 'oftto_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Add Colors to Social Links Menu', 'options-for-twenty-twenty-one');
            $control_description = __('Changes the color of the social icons to their relevant corporate colors.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('colored_social_links_menu', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('colored_social_links_menu', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_footer',
                'settings'      => 'colored_social_links_menu',
                'type'          => 'checkbox'
            ));

} else {

            $control_label = __('Add Icons and Colors to Social Links Menu', 'options-for-twenty-twenty-one');
            $control_description = __('Adds Linkedin, Telegram, TikTok, WhatsApp and Xing social icons and changes the color of the social icons to their relevant corporate colors.', 'options-for-twenty-twenty-one');
            ofttoCommon::add_hidden_control($wp_customize, 'colored_social_links_menu', 'oftto_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Social Links Icon Size', 'options-for-twenty-twenty-one');
            $control_description = __('Increase the size of the social link icons on larger screens.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('social_links_icon_size', array(
                'default'       => 24,
                'transport'     => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('social_links_icon_size', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_footer',
                'settings'      => 'social_links_icon_size',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 24,
                    'max'   => 96,
                    'step'  => 4
                )
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'social_links_icon_size', 'oftto_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Replace Site Title / Logo', 'options-for-twenty-twenty-one');
            $control_description = __('Provide alternate text / HTML to replace site title / logo.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('replace_site_title_logo', array(
                'default'           => '',
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'wp_kses_post'
            ));
            $wp_customize->add_control('replace_site_title_logo', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_footer',
                'settings'      => 'replace_site_title_logo',
                'type'          => 'text'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'replace_site_title_logo', 'oftto_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Replace "Powered by" Text', 'options-for-twenty-twenty-one');
            $control_description = __('Provide alternate text / HTML to replace "Proudly powered by Wordpress".', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('replace_powered_by_wordpress', array(
                'default'           => '',
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'wp_kses_post'
            ));
            $wp_customize->add_control('replace_powered_by_wordpress', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftto_footer',
                'settings'      => 'replace_powered_by_wordpress',
                'type'          => 'text'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'replace_powered_by_wordpress', 'oftto_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Dark Mode On by Default', 'options-for-twenty-twenty-one');
            $control_description = __('Enable Dark Mode when a user first visits the site.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('dark_mode_on', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttoCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('dark_mode_on', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'colors',
                'settings'      => 'dark_mode_on',
                'type'          => 'checkbox',
                'active_callback' => 'options_for_twenty_twenty_one_premium_class::oftto_is_dark_mode_enabled'
            ));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'dark_mode_on', 'colors', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Dark Mode Background Image', 'options-for-twenty-twenty-one');
            $control_description = __('Choose an alternative background image to use for Dark Mode.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('dark_mode_background_image', array(
                'default'           => false,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, 'dark_mode_background_image', array(
                'mime_type'     => 'image',
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'colors',
                'settings'      => 'dark_mode_background_image',
                'active_callback' => 'options_for_twenty_twenty_one_premium_class::oftto_is_dark_mode_enabled'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'dark_mode_background_image', 'colors', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Dark Mode Logo', 'options-for-twenty-twenty-one');
            $control_description = __('Choose an alternative logo to use for Dark Mode.', 'options-for-twenty-twenty-one');

if (ofttoPremium::request_permission() == true) {

            $wp_customize->add_setting('dark_mode_logo', array(
                'default'           => false,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, 'dark_mode_logo', array(
                'mime_type'     => 'image',
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'colors',
                'settings'      => 'dark_mode_logo',
                'active_callback' => 'options_for_twenty_twenty_one_premium_class::oftto_is_dark_mode_enabled'
            )));

} else {

            ofttoCommon::add_hidden_control($wp_customize, 'dark_mode_logo', 'colors', $control_label, $control_description . ' ' . $upgrade_nag);

}

        }

        function oftto_header_output() {

            global $post;

?>
<!--Customizer CSS-->
<style type="text/css">
<?php

if (ofttoPremium::request_permission()) {

            $mod = get_theme_mod('dark_mode_background_image');

            if (self::oftto_is_dark_mode_enabled() && $mod) {

?>
body.custom-background.is-dark-theme {
    background-image: url("<?php echo (wp_get_attachment_image_src($mod, 'full') ? wp_get_attachment_image_src($mod, 'full')[0] : ''); ?>");
}
<?php

            }

            if (twenty_twenty_one_can_show_post_thumbnail() && is_singular() && get_theme_mod('featured_background_image')) {

?>
body.page.custom-background, body.single.custom-background {
    background-image: none;
}
<?php

            }

            if (get_theme_mod('left_sidebar')) {

?>
@media (min-width: 482px) {
    #content-wrapper {
        flex-direction: row-reverse;
    }
    #content-wrapper>#sidebar {
        padding: 0 30px 0 0;
    }
}
<?php

            }

            $mod = absint(get_theme_mod('sidebar_width'));

            if ($mod) {

?>
@media (min-width: 482px) {
    #content-wrapper>#content {
        width: <?php echo 100 - $mod; ?>%;
    }
    #content-wrapper>#sidebar {
        width: <?php echo $mod; ?>%;
    }
}
<?php

            }

            $mod = absint(get_theme_mod('sidebar_min_width'));

            if ($mod) {

?>
@media (min-width: 482px) {
    #content-wrapper>#content {
        max-width: calc(100% - <?php echo $mod; ?>px);
    }
    #content-wrapper>#sidebar {
        min-width: <?php echo $mod; ?>px;
    }
}
<?php

            }

            if (is_active_sidebar('sidebar-3')) {

?>
#masthead #header-sidebar {
    width: 100%;

}
#masthead #header-sidebar * {
	margin: 0;
	padding: 0;
}
#masthead #header-sidebar .widget_nav_menu ul {
    display: flex;
    justify-content: flex-start;
    flex-wrap: wrap;
    list-style: none;
    margin: 0;
    max-width: none;
    padding-left: 0;
    position: relative;
    justify-content: center;
}
#masthead #header-sidebar .widget_nav_menu ul .menu-item {
    display: flex;
    margin: 0;
    width: inherit;
    position: relative;
}
#masthead #header-sidebar .widget_nav_menu ul .menu-item a {
    font-size: 1.25rem;
    line-height: 1.25rem;
    padding-left: 0.94rem;
    padding-right: 0.94rem;
}
<?php

            }

            if (twenty_twenty_one_can_show_post_thumbnail() && is_singular() && get_theme_mod('featured_header_image')) {

?>
#masthead-wrapper {
background-image: none;
}
<?php

            }

            if (self::oftto_has_masthead_wrapper()) {

                $mod = absint(get_theme_mod('header_gradient_height'));

                if ($mod) {

                    $gradient_color = get_theme_mod('header_gradient_color');
                    $gradient_opacity = absint(get_theme_mod('header_gradient_opacity'));

                    if (!$gradient_color) { $gradient_color = 'white'; }

                    if (!$gradient_opacity) { $gradient_opacity = 30; }

                    $gradient_opacity = $gradient_opacity / 100;
                    list($r, $g, $b) = array_map('hexdec', str_split(ltrim($gradient_color, '#'), 2));

?>
#masthead-wrapper {
    position: relative;
}
#masthead-wrapper:before {
    content: "";
    position: absolute;
    height: <?php echo $mod; ?>%;
    background: linear-gradient(to bottom, rgba(<?php echo $r; ?>, <?php echo $g; ?>, <?php echo $b; ?>, 0) 0%, rgba(<?php echo $r; ?>, <?php echo $g; ?>, <?php echo $b; ?>, <?php echo $gradient_opacity; ?>) 75%, rgba(<?php echo $r; ?>, <?php echo $g; ?>, <?php echo $b; ?>, <?php echo $gradient_opacity; ?>) 100%);
    bottom: 0;
    left: 0;
    right: 0;
}
#masthead>.site-branding {
    z-index: 1;
}
<?php

                }

            }

            $mod = get_theme_mod('inline_logo');

            if (options_for_twenty_twenty_one_class::oftto_are_title_and_tagline_displayed() && $mod) {

                if (in_array($mod, array('on', 'mobile'), true)) {

?>
@media only screen and (max-width: 481px) {
    .site-header > .site-logo {
        width: auto;
        padding: 0;
        border: none;
    }
    .site-header {
        flex-wrap: nowrap;
    }
}
<?php

                }

                if (in_array($mod, array('on', 'desktop'), true)) {

?>
@media only screen and (min-width: 482px) {
	.site-header > .site-logo {
		width: auto;
		padding: 0;
		border: none;
		margin-right: 30px;
	}
    .site-header {
        flex-wrap: nowrap;
    }
}
<?php

                }

            }

            $mod = absint(get_theme_mod('header_text_shadow_width'));

            if ($mod) {

                $mod = $mod - 1;

                $text_shadow_color = get_theme_mod('header_text_shadow_color');

                if (!$text_shadow_color) { $text_shadow_color = 'white'; }

?>
#masthead * {
	text-shadow: 1px 1px <?php echo $mod; ?>px <?php echo $text_shadow_color; ?>,
		1px -1px <?php echo $mod; ?>px <?php echo $text_shadow_color; ?>,
		-1px 1px <?php echo $mod; ?>px <?php echo $text_shadow_color; ?>,
		-1px -1px <?php echo $mod; ?>px <?php echo $text_shadow_color; ?>;
}
<?php

            }

            if (get_theme_mod('desktop_nav_on_mobile')) {

?>
@media only screen and (max-width: 481px) {

	.admin-bar .primary-navigation {
		top: initial;
	}

	.primary-navigation {
		position: relative;
		margin-left: auto;
	}

	.menu-button-container {
		display: none;
	}

	.admin-bar .primary-navigation > .primary-menu-container {
		top: initial;
	}

	.primary-navigation > .primary-menu-container {
		visibility: visible;
		opacity: 1;
		position: relative;
		padding: 0;
		background-color: transparent;
		overflow: initial;
		transform: none;
		z-index: auto;
		border: none;
		height: auto;
	}

	.primary-navigation > div > .menu-wrapper {
		padding-bottom: 0;
	}

	.primary-navigation .primary-menu-container > ul > .menu-item {
		display: flex;
	}

	.primary-navigation > div > .menu-wrapper li {
		margin: 0;
		width: inherit;
	}

	.primary-navigation .primary-menu-container > ul > .menu-item > a {
		padding-left: var(--primary-nav--padding);
		padding-right: var(--primary-nav--padding);
	}

	.primary-navigation > div > .menu-wrapper .sub-menu-toggle {
		display: flex;
	}

	.primary-navigation .primary-menu-container > ul > .menu-item > a + .sub-menu-toggle {
		margin-left: calc(5px - var(--primary-nav--padding));
	}

	.primary-navigation > .primary-menu-container ul > li .sub-menu-toggle[aria-expanded=false] ~ ul {
		display: none;
	}

	.primary-navigation > div > .menu-wrapper > li > .sub-menu {
		left: 0;
		margin: 0;
		min-width: max-content;
		position: absolute;
		top: 100%;
		padding-top: 3px;
		transition: all 0.5s ease;
		z-index: 88888;
	}

	.primary-navigation > div > .menu-wrapper > li > .sub-menu:before, .primary-navigation > div > .menu-wrapper > li > .sub-menu:after {
		content: "";
		display: block;
		position: absolute;
		width: 0;
		top: -10px;
		left: var(--global--spacing-horizontal);
		border-style: solid;
		border-color: var(--primary-nav--border-color) transparent;
		border-width: 0 7px 10px 7px;
	}

	.primary-navigation > div > .menu-wrapper > li > .sub-menu:after {
		top: -9px;
		border-color: var(--global--color-background) transparent;
	}

}
<?php

            }

            $mod = absint(get_theme_mod('mobile_nav_breakpoint'));

            $mobile_breakpoint = ($mod ? $mod + 481 : 481);

            if ($mod) {

                if (!options_for_twenty_twenty_one_class::oftto_are_title_and_tagline_displayed()) {

?>
@media only screen and (min-width: 482px) and (max-width: <?php echo $mobile_breakpoint; ?>px) {
    .site-header {
        position: relative;
    }
    .primary-navigation {
        position: absolute;
        right: 0;
    }
}
<?php

                }

?>
@media only screen and (max-width: <?php echo $mobile_breakpoint; ?>px) {
    .primary-navigation-open .primary-navigation {
        z-index: 3;
    }
    .primary-navigation-open .primary-navigation > .primary-menu-container {
        height: 100vh;
        overflow-x: hidden;
        overflow-y: auto;
        border: 2px solid transparent;
    }
    .primary-navigation > div > .menu-wrapper {
        padding-bottom: 100px;
        padding-left: 0;
    }
    .primary-navigation-open .primary-navigation {
        width: 100%;
        position: fixed;
    }
    .menu-button-container {
        display: flex;
    }
    .primary-navigation > .primary-menu-container {
        visibility: hidden;
        opacity: 0;
        position: fixed;
        padding-top: 71px;
        padding-left: 20px;
        padding-right: 20px;
        padding-bottom: 25px;
        background-color: var(--global--color-background);
        transition: all 0.15s ease-in-out;
        transform: translateX(0) translateY(0);
    }
    .primary-navigation > div > .menu-wrapper li {
        display: block;
        position: relative;
        width: 100%;
    }
    body:not(.primary-navigation-open) .site-header.has-logo.has-title-and-tagline .menu-button-container #primary-mobile-menu {
    	padding-left: calc(var(--global--spacing-horizontal) * 0.6 - 4.5px);
    	padding-right: calc(var(--global--spacing-horizontal) * 0.6 - 4.5px);
    	margin-right: calc(0px - var(--global--spacing-horizontal) * 0.6);
    }
    .has-logo.has-title-and-tagline .primary-navigation > .primary-menu-container {
        position: fixed;
        transform: translateY(0) translateX(100%);
    }
    body:not(.primary-navigation-open) .site-header.has-logo.has-title-and-tagline .menu-button-container {
        position: relative;
        padding-top: 0;
        margin-top: calc(0px - var(--button--padding-vertical)) + (0.25 * var(--global--spacing-unit))));
    }
    body:not(.primary-navigation-open) .site-header.has-logo.has-title-and-tagline .primary-navigation {
        position: relative;
        top: 0;
    }
    .primary-navigation-open .has-logo.has-title-and-tagline .primary-navigation > .primary-menu-container {
        transform: translateX(0) translateY(0);
    }
    .admin-bar .primary-navigation, .admin-bar .primary-navigation > .primary-menu-container {
    	top:32px;
    }
    .admin-bar .primary-navigation > .primary-menu-container {
        top: 0;
    }
    .primary-navigation-open .menu-button-container {
        width: auto;
    }
}
@media screen and (max-width: <?php echo min(782, $mobile_breakpoint); ?>px) {
    .admin-bar .primary-navigation {
    	top: 46px;
    }
}
<?php

            }

            if (get_theme_mod('sticky_mobile') || get_theme_mod('sticky_desktop')) {

?>
.site-header {
    z-index: 3;
}
<?php

            }

            $mod = get_theme_mod('sticky_mobile');

            if ($mod === 'site-navigation') {

?>
@media only screen and (max-width: <?php echo $mobile_breakpoint; ?>px) {
    #site-navigation {
        position: fixed;
        top: 0;
        width: 100%;
        z-index: 1000;
    }
    body:not(.primary-navigation-open) .site-header.has-logo.has-title-and-tagline .menu-button-container {
        padding-top: calc(0.5 * var(--global--spacing-vertical));
        padding-bottom: calc(0.25 * var(--global--spacing-vertical));
        margin-top: 0;
    }
    .menu-button-container {
        position: relative;
    }
    body:not(.primary-navigation-open) .site-header.has-logo.has-title-and-tagline .menu-button-container #primary-mobile-menu {
        padding: calc(var(--button--padding-vertical) - (0.25 * var(--global--spacing-unit))) calc(0.5 * var(--button--padding-horizontal));
        margin-right: 0;
    }
    .admin-bar #site-navigation {
	    top: 32px;
    }
}
@media screen and (max-width: <?php echo min($mobile_breakpoint, 782); ?>px) {
    .admin-bar #site-navigation {
        top: 46px;
    }
}
<?php

            } elseif ($mod === 'masthead-wrapper') {

?>
@media only screen and (max-width: <?php echo $mobile_breakpoint; ?>px) {
    #masthead-wrapper {
        position: fixed;
        top: 0;
        width: 100%;
        z-index: 1000;
    }
    .admin-bar #masthead-wrapper {
	    top: 32px;
    }
}
@media screen and (max-width: <?php echo min($mobile_breakpoint, 782); ?>px) {
    .admin-bar #masthead-wrapper {
        top: 46px;
    }
}
<?php

            } elseif ($mod === 'button') {

?>
@media only screen and (max-width: <?php echo $mobile_breakpoint; ?>px) {
	body:not(.primary-navigation-open) #masthead.site-header.has-menu #site-navigation {
	    height: calc(((var(--button--padding-vertical) - (0.25 * var(--global--spacing-unit))) * 2) + 24px);
	}
	body:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
        position: fixed;
        z-index: 1000;
		top: 1rem;
		right: 0;
        margin: 0;
        padding: 0;
    }
	body:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky #primary-mobile-menu {
        margin-right: 0;
    }

	body:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky .svg-icon {
        margin-left: 0;
    }
    body.admin-bar:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
		top: calc(1rem + 32px);
    }
}
@media (max-width: 600px) {
    body.admin-bar:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
		top: calc(1rem);
    }
}
@media (max-width: 782px) {
    body.admin-bar:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
		top: calc(1rem + 46px);
    }
}
@media (max-width: 600px) {
    body.admin-bar:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
		top: 1rem;
    }
}
<?php

            }

            $mod = get_theme_mod('sticky_desktop');

            if ($mod === 'site-navigation') {

?>
@media only screen and (min-width: 481px) {
    #site-navigation {
        position: fixed;
        top: 0;
        width: 100%;
        z-index: 1000;
    }
    .admin-bar #site-navigation {
	    top: 32px;
    }
}
<?php

                if ($mobile_breakpoint < 782) {

?>
@media screen and (min-width: <?php echo $mobile_breakpoint + 1; ?>px) and (max-width: 782px) {
    .admin-bar #site-navigation {
        top: 46px;
    }
}
<?php

                }

            } elseif ($mod === 'masthead-wrapper') {

?>
@media only screen and (min-width: 481px) {
    #masthead-wrapper {
        position: fixed;
        top: 0;
        width: 100%;
        z-index: 1000;
    }
    .admin-bar #masthead-wrapper {
	    top: 32px;
    }
}
<?php

                if ($mobile_breakpoint < 782) {

?>
@media screen and (min-width: <?php echo $mobile_breakpoint + 1; ?>px) and (max-width: 782px) {
    .admin-bar #masthead-wrapper {
        top: 46px;
    }
}
<?php

                }

            } elseif ($mod === 'button') {

?>
@media only screen and (min-width: 481px) {
	body.sticky-button:not(.primary-navigation-open) #masthead.site-header.has-menu #site-navigation {
	    height: calc(((var(--button--padding-vertical) - (0.25 * var(--global--spacing-unit))) * 2) + 24px);
	}
	body.sticky-button:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
	    display: block;
        position: fixed;
        z-index: 1000;
		top: 1rem;
		right: 0;
        margin: 0;
        padding: 0;
    }
	body.sticky-button:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky #primary-mobile-menu {
        margin-right: 0;
    }

	body.sticky-button:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky .svg-icon {
        margin-left: 0;
    }
    body.sticky-button.admin-bar:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
		top: calc(1rem + 32px);
    }
    .sticky-button.primary-navigation-open .primary-navigation {
        z-index: 3;
    }
    .sticky-button .primary-navigation > .primary-menu-container {
        display: none;
    }
    .sticky-button.primary-navigation-open .primary-navigation > .primary-menu-container {
        display: block;
        height: 100vh;
        overflow-x: hidden;
        overflow-y: auto;
        border: 2px solid transparent;
    }
    .sticky-button.primary-navigation > div > .menu-wrapper {
        padding-bottom: 100px;
        padding-left: 0;
    }
    .sticky-button.primary-navigation-open .primary-navigation {
        width: 100%;
        position: fixed;
    }
    .sticky-button .menu-button-container {
        display: flex;
    }
    .sticky-button .primary-navigation > .primary-menu-container {
        visibility: hidden;
        opacity: 0;
        position: fixed;
        padding-top: 71px;
        padding-left: 20px;
        padding-right: 20px;
        padding-bottom: 25px;
        background-color: var(--global--color-background);
        transition: all 0.15s ease-in-out;
        transform: translateX(0) translateY(0);
    }
    .sticky-button .primary-navigation > div > .menu-wrapper li {
        position: relative;
        width: 100%;
    }
    body.sticky-button:not(.primary-navigation-open) .site-header.has-logo.has-title-and-tagline .menu-button-container #primary-mobile-menu {
    	padding-left: calc(var(--global--spacing-horizontal) * 0.6 - 4.5px);
    	padding-right: calc(var(--global--spacing-horizontal) * 0.6 - 4.5px);
    	margin-right: calc(0px - var(--global--spacing-horizontal) * 0.6);
    }
    .sticky-button .has-logo.has-title-and-tagline .primary-navigation > .primary-menu-container {
        position: fixed;
        transform: translateY(0) translateX(100%);
    }
    body.sticky-button:not(.primary-navigation-open) .site-header.has-logo.has-title-and-tagline .menu-button-container {
        position: relative;
        padding-top: 0;
        margin-top: calc(0px - var(--button--padding-vertical)) + (0.25 * var(--global--spacing-unit))));
    }
    body.sticky-button:not(.primary-navigation-open) .site-header.has-logo.has-title-and-tagline .primary-navigation {
        position: relative;
    top: 0;
    }
    .sticky-button.primary-navigation-open .has-logo.has-title-and-tagline .primary-navigation > .primary-menu-container {
        transform: translateX(0) translateY(0);
    }
    .sticky-button.admin-bar .primary-navigation, .admin-bar .primary-navigation > .primary-menu-container {
    	top:32px;
    }
    .sticky-button.admin-bar .primary-navigation > .primary-menu-container {
        top: 0;
    }
    .sticky-button.primary-navigation-open .menu-button-container {
        width: auto;
    }
    .sticky-button.primary-navigation-open .primary-navigation > .primary-menu-container {
        visibility: visible;
        opacity: 1;
    }
}
@media (max-width: 600px) {
    body.sticky-button.admin-bar:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
		top: calc(1rem);
    }
}
@media (max-width: 782px) {
    body.sticky-button.admin-bar:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
		top: calc(1rem + 46px);
    }
    .sticky-button.admin-bar .primary-navigation {
    	top: 46px;
    }
}
@media (max-width: 600px) {
    body.sticky-button.admin-bar:not(.primary-navigation-open) #masthead.site-header.has-menu .menu-button-container.sticky {
		top: 1rem;
    }
}
<?php

            }

            if (get_theme_mod('sticky_menu_dropshadow') && (get_theme_mod('sticky_mobile') == 'site-navigation' || get_theme_mod('sticky_mobile') == 'masthead-wrapper')) {

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
@media (max-width: <?php echo $mobile_breakpoint; ?>px) {
    #<?php echo get_theme_mod('sticky_mobile'); ?> {
        transition: box-shadow 0.3s ease-in-out;
    }
    #<?php echo get_theme_mod('sticky_mobile'); ?>.shadow {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                } else {

?>
@media (max-width: <?php echo $mobile_breakpoint; ?>px) {
    #<?php echo get_theme_mod('sticky_mobile'); ?> {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                }

            }

            if (get_theme_mod('sticky_menu_dropshadow') && (get_theme_mod('sticky_desktop') == 'site-navigation' || get_theme_mod('sticky_desktop') == 'masthead-wrapper')) {

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
@media (min-width: <?php echo $mobile_breakpoint + 1; ?>px) {
    #<?php echo get_theme_mod('sticky_desktop'); ?> {
        transition: box-shadow 0.6s ease-in-out;
    }
    #<?php echo get_theme_mod('sticky_desktop'); ?>.shadow {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                } else {

?>
@media (min-width: <?php echo $mobile_breakpoint + 1; ?>px) {
    #<?php echo get_theme_mod('sticky_desktop'); ?> {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                }

            }

            if (get_theme_mod('sticky_menu_dropshadow')) {

?>
#site-navigation .sticky {
<?php

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
    transform: scale(0.8, 0.8);
    transition: box-shadow 0.3s ease-in-out, transform 0.3s ease-in-out;
    border: 1px solid rgba(0,0,0,0.1);
}
#site-navigation .shadow {
    box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    transform: scale(1, 1);
}
#site-navigation .sticky:hover {
    transform: scale(1, 1);
<?php

                }

?>
    box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
}
<?php

            }

            if (get_theme_mod('mobile_nav_flyout')) {

                if ($mobile_breakpoint > 481 || get_theme_mod('mobile_nav_on_desktop')) {

                    if (get_theme_mod('mobile_nav_on_desktop')) {

?>
@media only screen and (min-width: 481px) {
<?php

                    } else {

?>
@media only screen and (min-width: 481px) and (max-width: <?php echo $mobile_breakpoint; ?>px) {
<?php

                    }

?>

    .primary-navigation-open .has-title-and-tagline .primary-navigation {
		position: relative;
	}

    .primary-navigation > .primary-menu-container,
    .primary-navigation-open .primary-navigation > .primary-menu-container,
    .primary-navigation-open .has-logo.has-title-and-tagline .primary-navigation > .primary-menu-container {
		position: relative;
	}

    .primary-navigation-open .primary-navigation {
		position: absolute;
		width: auto;
	}

    .has-title-and-tagline .primary-navigation > .primary-menu-container {
		display: none;
	}

    .primary-navigation-open .has-title-and-tagline .primary-navigation > .primary-menu-container {
		display: block;
	}

    .primary-navigation > .primary-menu-container,
    .primary-navigation-open .primary-navigation > .primary-menu-container {
		height: auto;
	}

    .primary-navigation > div > .menu-wrapper,
    .primary-navigation-open .primary-navigation > div > .menu-wrapper {
		display: block;
		padding-bottom: 0;
	}

    .primary-navigation-open .primary-navigation > div > .menu-wrapper li {
		width: auto;
	}

    .primary-navigation-open .primary-navigation > .primary-menu-container {
        overflow: visible;
    }

}
<?php

                }

?>
@media only screen and (min-width: 481px) {

    .sticky-button.primary-navigation-open .has-title-and-tagline .primary-navigation {
		position: fixed;
	}

    #site-navigation,
	.sticky-button.primary-navigation-open .primary-navigation {
		width: auto;
	}

    .sticky-button.primary-navigation-open .menu-button-container.sticky {
   		position: fixed;
    }

	.sticky-button.primary-navigation-open .primary-navigation > .primary-menu-container,
    .sticky-button.primary-navigation-open .has-logo.has-title-and-tagline .primary-navigation > .primary-menu-container {
		position: relative;
	}

	.sticky-button.primary-navigation-open .primary-navigation > div > .menu-wrapper {
		display: block;
		padding-bottom: 0;
	}

	.sticky-button.primary-navigation-open .primary-navigation > div > .menu-wrapper li {
		width: auto;
	}

	.sticky-button.primary-navigation-open .primary-navigation > .primary-menu-container {
		height: auto;
	}

}
<?php

            }

            $mod = absint(get_theme_mod('nav_border_width'));

            if ($mod) {

?>
@media only screen and (min-width: <?php echo $mobile_breakpoint + 1; ?>px) {
    .primary-navigation .primary-menu-container > ul > .menu-item {
        border-width: <?php echo $mod; ?>px;
        border-color: <?php echo get_theme_mod('nav_border_color') ? get_theme_mod('nav_border_color') : 'var(--global--color-primary)'; ?>;
        border-style: <?php echo get_theme_mod('nav_border_style') ? get_theme_mod('nav_border_style') : 'solid'; ?>;
    }
}
<?php

            }

            $mod = get_theme_mod('nav_item_background_color');

            if ($mod) {

?>
@media only screen and (min-width: <?php echo $mobile_breakpoint + 1; ?>px) {
    .primary-navigation .primary-menu-container > ul > .menu-item {
        background-color: <?php echo $mod; ?>;
    }
}
<?php

            }

            $mod = absint(get_theme_mod('nav_item_border_radius'));

            if ($mod) {

?>
@media only screen and (min-width: <?php echo $mobile_breakpoint + 1; ?>px) {
    .primary-navigation .primary-menu-container > ul > .menu-item {
        border-radius: <?php echo $mod / 1000; ?>rem;
    }
}
<?php

            }

            $mod = absint(get_theme_mod('nav_item_margin'));

            if ($mod) {

?>
@media only screen and (min-width: <?php echo $mobile_breakpoint + 1; ?>px) {
    .primary-navigation .primary-menu-container > ul > .menu-item {
        margin: 0 <?php echo $mod; ?>px;
    }
	.primary-navigation .primary-menu-container > ul > .menu-item:last-child {
		margin-right: 0;
    }
	.primary-navigation .primary-menu-container > ul > .menu-item:first-child {
		margin-left: 0;
    }
}
<?php

            }

            if (get_theme_mod('hide_submenu_toggle')) {

?>
.primary-navigation .primary-menu-container > ul > .menu-item > a + .sub-menu-toggle {
display: none;
}
<?php

            }

            if (get_theme_mod('second_level_submenus')) {

?>
@media only screen and (min-width: <?php echo $mobile_breakpoint + 1; ?>px) {
    .primary-navigation .sub-menu>li>.sub-menu,
    .primary-navigation .sub-menu>li>.sub-menu>li>.sub-menu>li>.sub-menu{
        position: absolute;
        min-width: max-content;
        max-width: none;
        top: 90%;
        left: 0;
        right: auto;
        display: none;
        margin: 0;
        padding: 0;
        list-style: none;
        margin-left: 30px;
        border: 1px solid var(--primary-nav--border-color);
        z-index: 88888;
        background: inherit;
    }
    .primary-navigation .sub-menu>li>.sub-menu>li>.sub-menu {
        margin-left: 0;
        margin-right: 30px;
        left: auto;
        right: 0;
    }
    .primary-navigation .sub-menu>li:hover>.sub-menu {
        display: block !important;
    }
    .primary-navigation .sub-menu>li>.sub-menu>li {
        float: none;
        margin-top: 2px;
        max-width: 250px;
    }
<?php

                if (!get_theme_mod('hide_submenu_caret')) {

?>
    .primary-navigation .sub-menu>li>.sub-menu:before,
    .primary-navigation .sub-menu>li>.sub-menu:after,
    .primary-navigation .sub-menu>li>.sub-menu>li>.sub-menu>li>.sub-menu:before,
    .primary-navigation .sub-menu>li>.sub-menu>li>.sub-menu>li>.sub-menu:after {
        content: "";
        display: block;
        position: absolute;
        width: 0;
        top: -10px;
        left: 15px;
        right: auto;
        border-style: solid;
        border-color: var(--primary-nav--border-color) transparent;
        border-width: 0 7px 10px 7px;
    }
    .primary-navigation .sub-menu>li>.sub-menu>li>.sub-menu:before,
    .primary-navigation .sub-menu>li>.sub-menu>li>.sub-menu:after {
        left: auto;
        right: 15px;
    }
    .primary-navigation .sub-menu>li>.sub-menu:after {
        top: -9px !important;
        border-color: <?php echo get_theme_mod('nav_submenu_background_color') ? get_theme_mod('nav_submenu_background_color') : 'var(--global--color-background)'; ?> transparent !important;
    }
<?php

                }

                $mod = get_theme_mod('second_submenu_background_color');

                if ($mod) {
?>
    .primary-navigation .sub-menu .sub-menu:after {
        border-bottom-color: <?php echo $mod; ?>;
    }
    .primary-navigation > div > .menu-wrapper > li .sub-menu .sub-menu, .primary-navigation > div > .menu-wrapper > li .sub-menu .sub-menu li {
        background-color: <?php echo $mod; ?>;
    }
<?php

                }

?>
}
<?php

            }

            if (get_theme_mod('mobile_submenus')) {

?>
@media only screen and (max-width: <?php echo $mobile_breakpoint; ?>px) {
    .primary-navigation > div > .menu-wrapper .sub-menu-toggle {
        display: flex;
    }
    .primary-navigation .sub-menu {
        margin-left: 0;
        width: 100%;
    }
    .primary-navigation .primary-menu-container > ul > .menu-item > a + .sub-menu-toggle {
        position: absolute;
        right: 0;
        top: 0;
        display: flex;
    }
    .primary-navigation > div > .menu-wrapper > li > .sub-menu {
        position: relative;
        top: auto;
    }
}
.primary-navigation > .primary-menu-container ul > li .sub-menu-toggle[aria-expanded=false] ~ ul {
    display: none;
}
.primary-navigation .primary-menu-container > ul > .menu-item {
    display: flex;
    flex-wrap: wrap;
}
<?php

            }

            if (get_theme_mod('primary_nav_search')) {

?>
#menu-item-search {
    padding: var(--primary-nav--padding) var(--primary-nav--padding);
    cursor: pointer;
}
#menu-item-search .svg-icon {
	fill: var(--primary-nav--color-text);
	width: 1.125rem;
	height: 1.125rem;
}

#search-modal {
	display: none;
	position: fixed;
	bottom: 0;
	top: 0;
	left: 0;
	right: 0;
	z-index: 1010;
}
.admin-bar #search-modal {
	top: 32px;
}
@media screen and (max-width: 782px) {
    .admin-bar #search-modal {
        top: 46px;
    }
}
#search-modal-inner {
	display: flex;
}
#search-modal-inner label {
	display: none;
}
#search-modal-inner .search-form {
	max-width: none;
	width: 80%;
}
#search-modal-inner input:not(.search-field) {
	display: none;
}
#search-modal-inner input.search-field {
	margin: 0;
	width: 100%;
	font-size: 2rem;
	padding: 1rem 2rem;
}
#close-search-toggle {
	width: 20%;
	cursor: pointer;
}
#close-search-toggle .svg-icon {
	width: 3rem;
	height: 3rem;
}
#search-modal-excess {
	width: 100%;
	height: 100%;
}
#search-modal.show-modal {
	display: block;
}
#close-search-toggle:hover {
    background-color: var(--global--color-background);
}
#mobile-item-search {
    padding: 10px 15px;
}
@media screen and (max-width: 481px) {
    #mobile-item-search {
        display: block;
    }
    #menu-item-search {
        display: none;
    }
    #close-search-toggle {
	    padding: 15px 7px;
    }
}
<?php

            }

            if (is_singular() && get_post_meta(get_the_ID(), 'oftto_hide_site_header', true) == '1') {

                if (get_theme_mod('hide_site_header')) { $show_or_hide = 'block'; } else { $show_or_hide = 'none'; }

?>
.site-header {
    display: <?php echo $show_or_hide; ?>;
}
<?php

            }

            if (get_theme_mod('hide_page_headers')) { $show_or_hide = 'block'; } else { $show_or_hide = 'none'; }

            if (is_singular() && get_post_meta(get_the_ID(), 'oftto_hide_header', true) == '1') {

?>
.page .entry-header, .single .entry-header {
    display: <?php echo $show_or_hide; ?>;
}
<?php

            } elseif (is_home() && '1' === get_post_meta(get_option('page_for_posts'), 'oftto_hide_header', true)) {

?>
.blog .page-header {
    display: <?php echo $show_or_hide; ?>;
}
<?php

            }

            if (get_theme_mod('hide_page_titles')) { $show_or_hide = 'block'; } else { $show_or_hide = 'none'; }

            if (is_singular() && '1' === get_post_meta(get_the_ID(), 'oftto_hide_header_title', true)) {

?>
.page .entry-header .entry-title, .single .entry-header .entry-title {
    display: <?php echo $show_or_hide; ?>;
}
<?php

            } elseif (is_home() && '1' === get_post_meta(get_option('page_for_posts'), 'oftto_hide_header_title', true)) {

?>
.blog .page-header .page-title {
    display: <?php echo $show_or_hide; ?>;
}
<?php

            }

            if (is_singular() && get_post_meta(get_the_ID(), 'oftto_hide_featured_image', true) == '1') {

                if (get_theme_mod('hide_featured_images')) { $show_or_hide = 'block'; } else { $show_or_hide = 'none'; }

?>
.page .entry-header .post-thumbnail, .single .entry-header .post-thumbnail {
    display: <?php echo $show_or_hide; ?>;
}
<?php

            }

            if (is_singular() && get_post_meta(get_the_ID(), 'oftto_hide_widget_area', true) == '1') {

?>
.page #page>.widget-area, .single #page>.footer-wrapper .widget-area,
.page #footer-wrapper .widget-area, .single #footer-wrapper .widget-area {
    display: none;
}
<?php

            }

            if (is_singular() && get_post_meta(get_the_ID(), 'oftto_hide_footer', true) == '1') {

?>
.page footer, .single footer {
    display: none;
}
<?php

            }

            $mod = absint(get_theme_mod('alignwide_max_width'));

            if ($mod) {

?>
@media only screen and (min-width: 822px) {
	:root {
		--responsive--alignwide-width: min(calc(100vw - 8 * var(--global--spacing-horizontal)), <?php echo $mod; ?>px);
	}
}
<?php

            }

            if (get_theme_mod('remove_archive_title_prefix')) {

                add_filter('get_the_archive_title_prefix', array($this, 'oftto_remove_archive_title_prefix'));

            }

            $mod = get_theme_mod('content_background_color');

            if ($mod && is_singular()) {

?>
.entry-content-wrapper {
	background-color: <?php echo $mod; ?>;
}
.entry-content-wrapper {
	overflow: auto;
}
<?php

            }

            if (!get_theme_mod('hide_featured_images') && get_theme_mod('archive_featured_images')) {

?>
.page-header .post-thumbnail {
    margin-left: auto;
    margin-right: auto;
    width: var(--responsive--alignwide-width);
    max-width: var(--responsive--alignfull-width);
}
<?php

            }

            if (get_theme_mod('parallax_cover_block')) {

?>
.wp-block-cover {
	overflow: hidden;
}
<?php

            }

            $taxonomies = get_theme_mod('archive_grid_template');

            if ($taxonomies && is_array($taxonomies)) {

                foreach ($taxonomies as $taxonomy) {

                    switch ($taxonomy) {

                        case 'blog':

                            break;

                        case 'category':

                            break;

                        case 'post_tag':

                            $taxonomy = 'tag';
                            break;

                        default:

                            $taxonomy = 'tax-' . $taxonomy;
                            break;

                    }

                    $mod = absint(get_theme_mod('grid_box_shape'));

                    if ($mod) {

?>
.<?php echo $taxonomy; ?> .site-main>article>.entry-header::after {
    padding-bottom: <?php echo $mod; ?>%;
}
<?php

                    }

                    $mod = absint(get_theme_mod('grid_border_width'));

                    if ($mod) {

?>
.<?php echo $taxonomy; ?> .site-main>article:not(.has-post-thumbnail)>.entry-header {
    border-width: <?php echo $mod - 1; ?>px;
}
<?php

                    }

                    $mod = get_theme_mod('grid_border_color');

                    if ($mod) {

?>
.<?php echo $taxonomy; ?> .site-main>article:not(.has-post-thumbnail)>.entry-header {
    border-color: <?php echo $mod; ?>;
}
<?php

                    }

                    $mod = get_theme_mod('grid_border_style');

                    if ($mod) {

?>
.<?php echo $taxonomy; ?> .site-main>article:not(.has-post-thumbnail)>.entry-header {
    border-style: <?php echo $mod; ?>;
}
<?php

                    }

?>
@media (max-width: 482px) {
<?php

                    $mod = absint(get_theme_mod('grid_columns_small'));

                    if ($mod) {

                        $mod = floor(100000 / $mod) / 1000;

?>
	.<?php echo $taxonomy; ?> .site-main>article {
        width: <?php echo $mod; ?>%;
    }
<?php

                    }

                    $mod = absint(get_theme_mod('grid_font_size_small')) / 10;

                    if ($mod) {

?>
	.<?php echo $taxonomy; ?> .site-main>article>.entry-header>.entry-title {
        font-size: <?php echo $mod; ?>vw;
    }
<?php

                    }

?>
}
@media (min-width: 482px) and (max-width: 821px) {
<?php

                    $mod = absint(get_theme_mod('grid_columns_medium'));

                    if ($mod) {

                        $mod = floor(100000 / $mod) / 1000;

?>
	.<?php echo $taxonomy; ?> .site-main>article {
        width: <?php echo $mod; ?>%;
    }
<?php

                    }

                    $mod = absint(get_theme_mod('grid_font_size_medium')) / 10;

                    if ($mod) {

?>
	.<?php echo $taxonomy; ?> .site-main>article>.entry-header>.entry-title {
        font-size: <?php echo $mod; ?>vw;
    }
<?php

                    }

?>
}
@media (min-width: 822px) {
<?php

                    $mod = absint(get_theme_mod('grid_columns_large'));

                    if ($mod) {

                        $mod = floor(100000 / $mod) / 1000;

?>
	.<?php echo $taxonomy; ?> .site-main>article {
        width: <?php echo $mod; ?>%;
    }
<?php

                    }

                    $mod = absint(get_theme_mod('grid_font_size_large')) / 10;

                    if ($mod) {

?>
	.<?php echo $taxonomy; ?> .site-main>article>.entry-header>.entry-title {
        font-size: <?php echo $mod; ?>vw;
    }
<?php

                    }

?>
}
<?php

                    $mod = absint(get_theme_mod('grid_title_shadow_width'));

                    if ($mod > 1) {

                        $mod = $mod - 2;
                        $text_shadow_color = get_theme_mod('grid_title_shadow_color');

                        if (!$text_shadow_color) { $text_shadow_color = 'var(--global--color-background)'; }

?>
.<?php echo $taxonomy; ?> .site-main>article.has-post-thumbnail>.entry-header>.entry-title>a {
	text-shadow: 1px 1px <?php echo $mod; ?>px <?php echo $text_shadow_color; ?>,
		1px -1px <?php echo $mod; ?>px <?php echo $text_shadow_color; ?>,
		-1px 1px <?php echo $mod; ?>px <?php echo $text_shadow_color; ?>,
		-1px -1px <?php echo $mod; ?>px <?php echo $text_shadow_color; ?>;
}
<?php

                    } elseif ($mod) {

?>
.<?php echo $taxonomy; ?> .site-main>article.has-post-thumbnail>.entry-header>.entry-title>a {
	text-shadow: none;
}
<?php

                    }

                    ofttoCommon::generate_css('.' . $taxonomy . ' .site-main>article>.entry-header>.entry-title>a', 'text-transform', 'grid_title_text_transform');

                    if (get_theme_mod('grid_hover_animation')) {

?>
.<?php echo $taxonomy; ?> .site-main>article>.entry-header>.entry-title>a {
	transition: background-color 0.3s ease-in-out, color 0.3s ease-in-out, text-shadow 0.3s ease-in-out;
}
.<?php echo $taxonomy; ?> .site-main>article>.entry-header>.entry-title>a:hover {
	background-color: <?php echo get_theme_mod('archive_post_title_color') ? get_theme_mod('archive_post_title_color') : 'var(--global--color-primary)'; ?>;
	color: <?php echo get_theme_mod('background_color') ? '#' . get_theme_mod('background_color') : 'var(--global--color-background)'; ?>;
	text-shadow: none;
}
<?php

                    }

                    if (get_theme_mod('grid_post_dates')) {

?>
.<?php echo $taxonomy; ?> .site-main>article>.entry-footer {
    display: block;
    text-align: center;
    padding: 0;
    margin: 0;
    border: none;
}
.<?php echo $taxonomy; ?> .entry-footer .post-taxonomies {
    display: none;
}
.<?php echo $taxonomy; ?> .entry-footer .posted-on {
    margin: 0.5rem 0 0 0;
}
<?php

                    }

                }

            }

            $taxonomies = get_theme_mod('archive_row_template');

            if ($taxonomies && is_array($taxonomies)) {

                foreach ($taxonomies as $taxonomy) {

                    switch ($taxonomy) {

                        case 'blog':

                            break;

                        case 'search':

                            break;

                        case 'category':

                            break;

                        case 'post_tag':

                            $taxonomy = 'tag';
                            break;

                        default:

                            $taxonomy = 'tax-' . $taxonomy;
                            break;

                    }

?>
.<?php echo $taxonomy; ?> .search-result-count {
    max-width: none;
}
.<?php echo $taxonomy; ?> .site-main>article {
	display: flex;
}
.<?php echo $taxonomy; ?> .site-main>article .post-thumbnail .wp-post-image {
    margin-top: 0;
}
.<?php echo $taxonomy; ?> .site-main>article>.entry-header, .<?php echo $taxonomy; ?> .site-main>article>.entry-content {
	width: 50%;
	padding: 1rem;
	margin-top: 0;
}
.<?php echo $taxonomy; ?> .site-main>article>.entry-footer {
	display: none;
}
<?php

                }

            }

            $taxonomies = get_theme_mod('archive_column_template');

            if ($taxonomies && is_array($taxonomies)) {

                foreach ($taxonomies as $taxonomy) {

                    switch ($taxonomy) {

                        case 'blog':

                            break;

                        case 'search':

                            break;

                        case 'category':

                            break;

                        case 'post_tag':

                            $taxonomy = 'tag';
                            break;

                        default:

                            $taxonomy = 'tax-' . $taxonomy;
                            break;

                    }

?>
.<?php echo $taxonomy; ?> .search-result-count {
    max-width: none;
}
.<?php echo $taxonomy; ?> .site-main {
	display: flex;
	flex-wrap: wrap;
	padding-left: 0;
	padding-right: 0;
	width: 100%;
}
@media (min-width: 482px) {
	.<?php echo $taxonomy; ?> .site-main {
        padding-left: 1rem;
        padding-right: 1rem;
    }
}
.<?php echo $taxonomy; ?> .site-main>* {
	padding: 1rem;
	width: 100%;
}
.<?php echo $taxonomy; ?> .site-main>article {
	margin: 0;
}
@media (max-width: 482px) {
<?php

                    $mod = (absint(get_theme_mod('column_columns_small')) ? absint(get_theme_mod('column_columns_small')) : 1);
                    $mod = floor(100000 / $mod) / 1000;

?>
	.<?php echo $taxonomy; ?> .site-main>article {
        width: <?php echo $mod; ?>%;
    }
}
@media (min-width: 482px) and (max-width: 821px) {
<?php

                    $mod = (absint(get_theme_mod('column_columns_medium')) ? absint(get_theme_mod('column_columns_medium')) : 2);
                    $mod = floor(100000 / $mod) / 1000;

?>
	.<?php echo $taxonomy; ?> .site-main>article {
        width: <?php echo $mod; ?>%;
    }
}
@media (min-width: 822px) {
<?php

                    $mod = (absint(get_theme_mod('column_columns_large')) ? absint(get_theme_mod('column_columns_large')) : 3);
                    $mod = floor(100000 / $mod) / 1000;

?>
	.<?php echo $taxonomy; ?> .site-main>article {
        width: <?php echo $mod; ?>%;
    }
}
.<?php echo $taxonomy; ?> .site-main>article .more-link {
	margin-top: 30px;
	display: table;
}
.<?php echo $taxonomy; ?> .site-main>article>.entry-header {
    margin-bottom: calc(2 * var(--global--spacing-vertical));
}
.<?php echo $taxonomy; ?> .site-main>article.has-post-thumbnail>.entry-header {
    margin-bottom: var(--global--spacing-vertical);
}
.<?php echo $taxonomy; ?> .site-main>article>.entry-header>.post-thumbnail figcaption,
.<?php echo $taxonomy; ?> .site-main>article>.entry-footer {
	display: none;
}
<?php

                    if (get_theme_mod('column_post_dates')) {

?>
.<?php echo $taxonomy; ?> .site-main>article>.entry-footer {
    display: block;
    text-align: center;
    padding: 0;
    margin: 0;
    border: none;
}
.<?php echo $taxonomy; ?> .entry-footer .post-taxonomies {
    display: none;
}
.<?php echo $taxonomy; ?> .entry-footer .posted-on {
    margin: 0.5rem 0 0 0;
}
<?php

                    }

                }

            }

            $taxonomies = get_theme_mod('archive_card_template');

            if ($taxonomies && is_array($taxonomies)) {

                foreach ($taxonomies as $taxonomy) {

                    switch ($taxonomy) {

                        case 'blog':

                            break;

                        case 'search':

                            break;

                        case 'category':

                            break;

                        case 'post_tag':

                            $taxonomy = 'tag';
                            break;

                        default:

                            $taxonomy = 'tax-' . $taxonomy;
                            break;

                    }

?>
.<?php echo $taxonomy; ?> .site-main {
    margin: 0 auto;
    max-width: var(--responsive--alignwide-width);
}
.<?php echo $taxonomy; ?> .site-main>article {
	box-shadow: 0 7px 17px 0 rgba(0, 0, 0, 0.2);
	padding: 4rem 4rem 0 4rem;
}
.<?php echo $taxonomy; ?> .site-main > article > .entry-footer {
    border-bottom: none;
}
@media screen and (max-width: 481px) {
    .<?php echo $taxonomy; ?> .site-main>article {
	    padding: 1rem 1rem 0 1rem;
    }
}
<?php

                }

            }





            if (get_theme_mod('remove_published_text')) {

                add_filter('gettext', array($this, 'oftto_replace_published_text'), 10, 3);

            }

            ofttoCommon::generate_css('#widget-area-wrapper', 'background-color', 'footer_widget_area_background_color');

            $social_icon_size = absint(get_theme_mod('social_links_icon_size'));
            $mod = get_theme_mod('fix_social_links');

            if ($mod) {

?>
@media screen and (min-width: 482px) {
    .footer-navigation {
        position: fixed;
        margin: 0;
        <?php echo $mod; ?>: 0;
        width: auto;
        transform: translate(0, -50%);
        top: 50vh;
        z-index: 3;
    }
    .footer-navigation-wrapper {
    	transition: 0.25s padding ease-out;
		display: block;
    }
    .footer-navigation-wrapper li {
    	display: block;
		line-height: normal;
    }
    .footer-navigation-wrapper li a {
    	margin-<?php echo $mod; ?>: -<?php echo (((($social_icon_size - 24) / 2) + 24) / 2); ?>px;
    	display: block;
    	padding: 0;
    }
    .footer-navigation-wrapper:hover {
    	padding-<?php echo $mod; ?>: calc(5px + <?php echo (((($social_icon_size - 24) / 2) + 24) / 2); ?>px);
    }
    .site-info {
        width: 100%;
    }
}
@media only screen and (min-width: 822px) {
    .footer-navigation-wrapper li a {
    	margin-<?php echo $mod; ?>: -<?php echo ($social_icon_size / 2); ?>px;
    }
    .footer-navigation-wrapper:hover {
    	padding-<?php echo $mod; ?>: calc(5px + <?php echo ($social_icon_size / 2); ?>px);
    }
}
<?php

            }

            $mod = get_theme_mod('fix_social_links_mobile');

            if ($mod) {

?>
@media screen and (max-width: 481px) {
    .footer-navigation {
        position: fixed;
        margin: 0;
        <?php echo $mod; ?>: 0;
        width: auto;
        transform: translate(0, -50%);
        top: 50vh;
        z-index: 3;
    }
    .footer-navigation-wrapper {
		display: block;
    }
    .footer-navigation-wrapper li {
    	display: block;
		line-height: normal;
    }
    .footer-navigation-wrapper li a {
    	display: block;
    	padding: 0;
    }
    .site-info {
        width: 100%;
    }
}
<?php

            }

            if (get_theme_mod('colored_social_links_menu')) {

?>
.footer-navigation-wrapper li .social-color-500px .svg-icon {
	fill: #222222;
}
.footer-navigation-wrapper li .social-color-amazon .svg-icon {
	fill: #e47911;
}
.footer-navigation-wrapper li .social-color-bandcamp .svg-icon {
	fill: #629aa9;
}
.footer-navigation-wrapper li .social-color-behance .svg-icon {
	fill: #053eff;
}
.footer-navigation-wrapper li .social-color-codepen .svg-icon {
	fill: #1e1f26;
}
.footer-navigation-wrapper li .social-color-deviantart .svg-icon {
	fill: #05cc47;
}
.footer-navigation-wrapper li .social-color-dribbble .svg-icon {
	fill: #ea4c89;
}
.footer-navigation-wrapper li .social-color-dropbox .svg-icon {
	fill: #3d9ae8;
}
.footer-navigation-wrapper li .social-color-etsy .svg-icon {
	fill: #eb6d20;
}
.footer-navigation-wrapper li .social-color-facebook .svg-icon {
	fill: #3b5998;
}
.footer-navigation-wrapper li .social-color-flickr .svg-icon {
	fill: #ff0084;
}
.footer-navigation-wrapper li .social-color-foursquare .svg-icon {
	fill: #fa4779;
}
.footer-navigation-wrapper li .social-color-goodreads .svg-icon {
	fill: #e9e5cd;
}
.footer-navigation-wrapper li .social-color-google .svg-icon {
	fill: #4285F4;
}
.footer-navigation-wrapper li .social-color-github .svg-icon {
	fill: #F1502F;
}
.footer-navigation-wrapper li .social-color-instagram .svg-icon {
	fill: #8a3ab9;
}
.footer-navigation-wrapper li .social-color-lastfm .svg-icon {
	fill: #D51007;
}
.footer-navigation-wrapper li .social-color-linkedin .svg-icon {
	fill: #2867B2;
}
.footer-navigation-wrapper li .social-color-mastodon .svg-icon {
	fill: #2b90d9;
}
.footer-navigation-wrapper li .social-color-meetup .svg-icon {
	fill: #ED1C40;
}
.footer-navigation-wrapper li .social-color-pinterest .svg-icon {
	fill: #E60023;
}
.footer-navigation-wrapper li .social-color-pocket .svg-icon {
	fill: #83ecb8;
}
.footer-navigation-wrapper li .social-color-reddit .svg-icon {
	fill: #FF4301;
}
.footer-navigation-wrapper li .social-color-skype .svg-icon {
	fill: #00AFF0;
}
.footer-navigation-wrapper li .social-color-snapchat .svg-icon {
	fill: #FEFC00;
}
.footer-navigation-wrapper li .social-color-soundcloud .svg-icon {
	fill: #FF9533;
}
.footer-navigation-wrapper li .social-color-spotify .svg-icon {
	fill: #1ed761;
}
.footer-navigation-wrapper li .social-color-tumblr .svg-icon {
	fill: #35465c;
}
.footer-navigation-wrapper li .social-color-twitch .svg-icon {
	fill: #9147fe;
}
.footer-navigation-wrapper li .social-color-twitter .svg-icon {
	fill: #0084b4;
}
.footer-navigation-wrapper li .social-color-vimeo .svg-icon {
	fill: #162221;
}
.footer-navigation-wrapper li .social-color-vk .svg-icon {
	fill: #4c75a3;
}
.footer-navigation-wrapper li .social-color-wordpress .svg-icon {
	fill: #21759b;
}
.footer-navigation-wrapper li .social-color-yelp .svg-icon {
	fill: #c41200;
}
.footer-navigation-wrapper li .social-color-youtube .svg-icon {
	fill: #ff0000;
}
.footer-navigation-wrapper li .social-color-xing .svg-icon {
	fill: #026466;
}
.footer-navigation-wrapper li .social-color-telegram .svg-icon {
	fill: #0088cc;
}
.footer-navigation-wrapper li .social-color-tiktok .svg-icon {
	fill: #010101;
}
.footer-navigation-wrapper li .social-color-whatsapp .svg-icon {
	fill: #075E54;
}
<?php

            }

            if ($social_icon_size) {
?>
@media only screen and (min-width: 482px) {
    .footer-navigation-wrapper li .svg-icon {
        width: <?php echo (($social_icon_size - 24) / 2) + 24; ?>px;
        height: <?php echo (($social_icon_size - 24) / 2) + 24; ?>px;
    }
    .footer-navigation-wrapper li a {
        font-size: <?php echo (($social_icon_size - 24) / 2) + 24; ?>px;
    }
}
@media only screen and (min-width: 822px) {
    .footer-navigation-wrapper li .svg-icon {
        width: <?php echo $social_icon_size; ?>px;
        height: <?php echo $social_icon_size; ?>px;
    }
    .footer-navigation-wrapper li a {
        font-size: <?php echo $social_icon_size; ?>px;
    }
}
<?php
            }

}

?>
</style> 
<!--/Customizer CSS-->
<?php

        }

        public function oftto_replace_published_text($translation, $text, $domain) {
 
            if ($text === 'Published in %s' && $domain == 'twentytwentyone') {

                $translation = '%s';

            } elseif ($text === 'Published %s' && $domain == 'twentytwentyone') {

                $translation = '%s';

            }

            return $translation;

        }

        function oftto_frontend_javascript() {

            if (ofttoPremium::request_permission()) {

                if (is_active_sidebar('sidebar-3')) {

?>
<aside id="header-sidebar">
<?php dynamic_sidebar('sidebar-3'); ?>
</aside>
<script type="text/javascript">
    (function () {
        document.getElementById('masthead').<?php echo (get_theme_mod('header_widget_area') ? 'append' : 'prepend'); ?>(document.getElementById('header-sidebar'));
    }());
</script>
<?php

                }

                $taxonomies = get_theme_mod('archive_row_template');

                if ($taxonomies && is_array($taxonomies)) {

                    foreach ($taxonomies as $taxonomy) {

                        switch ($taxonomy) {

                            case 'blog':

                                break;

                            case 'search':

                                break;

                            case 'category':

                                break;

                            case 'post_tag':

                                $taxonomy = 'tag';
                                break;

                            default:

                                $taxonomy = 'tax-' . $taxonomy;
                                break;

                        }

?>
<script type="text/javascript">
    (function() {
        if (document.body.classList.contains('<?php echo $taxonomy; ?>')) {
            Array.prototype.forEach.call(document.querySelectorAll('.site-main>article'), function(article) {
                article.getElementsByClassName('entry-content')[0].insertBefore(article.getElementsByClassName('entry-title')[0], article.getElementsByClassName('entry-content')[0].firstChild);
            });
        }
    })();
</script>
<?php

                    }

                }

                $taxonomies = get_theme_mod('archive_column_template');

                if ($taxonomies && is_array($taxonomies)) {

                    foreach ($taxonomies as $taxonomy) {

                        switch ($taxonomy) {

                            case 'blog':

                                break;

                            case 'search':

                                break;

                            case 'category':

                                break;

                            case 'post_tag':

                                $taxonomy = 'tag';
                                break;

                            default:

                                $taxonomy = 'tax-' . $taxonomy;
                                break;

                        }

?>
<script type="text/javascript">
    (function() {
        if (document.body.classList.contains('<?php echo $taxonomy; ?>')) {
            Array.prototype.forEach.call(document.querySelectorAll('.site-main>article'), function(article) {
                article.getElementsByClassName('entry-content')[0].insertBefore(article.getElementsByClassName('entry-title')[0], article.getElementsByClassName('entry-content')[0].firstChild);
            });
            Array.prototype.forEach.call(document.querySelectorAll('.site-main>article .more-link'), function(readMore) {
                readMore.classList.add('button');
            });
        }
    })();
</script>
<?php

                    }

                }

                $mod = absint(get_theme_mod('mobile_nav_breakpoint'));
                $mobile_breakpoint = ($mod ? $mod + 481 : 481);

                if (twenty_twenty_one_can_show_post_thumbnail() && is_singular() && get_theme_mod('featured_background_image')) {

?>
<script type="text/javascript">
    (function() {
        document.body.style.backgroundImage = 'url("' + document.querySelector('.post-thumbnail .wp-post-image').src + '")';
    })();
</script>
<?php

                }

                if (
                    get_theme_mod('sticky_mobile') === 'site-navigation' || get_theme_mod('sticky_desktop') === 'site-navigation' ||
                    get_theme_mod('sticky_mobile') === 'masthead-wrapper' || get_theme_mod('sticky_desktop') === 'masthead-wrapper'
                ) {

                    if (get_theme_mod('sticky_mobile') === 'site-navigation' || get_theme_mod('sticky_mobile') === 'masthead-wrapper') { $width_condition = 'document.body.clientWidth < ' . ($mobile_breakpoint + 1); }

                    if (get_theme_mod('sticky_desktop') === 'site-navigation' || get_theme_mod('sticky_desktop') === 'masthead-wrapper') { $width_condition = 'document.body.clientWidth >= 481'; }

                    if (
                        (get_theme_mod('sticky_mobile') === 'site-navigation' || get_theme_mod('sticky_mobile') === 'masthead-wrapper') &&
                        (get_theme_mod('sticky_desktop') === 'site-navigation' || get_theme_mod('sticky_desktop') === 'masthead-wrapper')
                    ) { $width_condition = '1 == 1'; }

?>
<script type="text/javascript">
    (function () {
        function setupWindowResize() {
            var windowResize;
            (windowResize = function(){
                if (<?php echo $width_condition; ?>) {
<?php
                    if (get_theme_mod('sticky_mobile') === 'site-navigation' || get_theme_mod('sticky_mobile') === 'masthead-wrapper') {

?>
                    if (document.body.clientWidth < <?php echo ($mobile_breakpoint + 1); ?>) {
                        document.body.style.marginTop = document.getElementById('<?php echo get_theme_mod('sticky_mobile'); ?>').clientHeight + 'px';
                    }
<?php

                    }

                    if (get_theme_mod('sticky_desktop') === 'site-navigation' || get_theme_mod('sticky_desktop') === 'masthead-wrapper') {

?>
                    if (document.body.clientWidth >= <?php echo ($mobile_breakpoint + 1); ?>) {
                        document.body.style.marginTop = document.getElementById('<?php echo get_theme_mod('sticky_desktop'); ?>').clientHeight + 'px';
                    }
<?php

                    }

?>
                } else {
                    document.body.style.marginTop = 0;
                }
            }).call();
            window.addEventListener('resize', windowResize);
        }
        if (
            document.readyState === 'complete' ||
            (document.readyState !== 'loading' && !document.documentElement.doScroll)
        ) {
            setupWindowResize();
        } else {
            document.addEventListener('DOMContentLoaded', setupWindowResize());
        }
        window.addEventListener('scroll', function() {
<?php
                    if (get_theme_mod('sticky_mobile') === 'site-navigation' || get_theme_mod('sticky_mobile') === 'masthead-wrapper') {

?>
            var mobileHeader = document.getElementById('<?php echo get_theme_mod('sticky_mobile'); ?>');
            if (document.body.clientWidth < <?php echo ($mobile_breakpoint + 1); ?> && !mobileHeader.classList.contains('shadow')) {
                mobileHeader.classList.add('shadow');
                setTimeout(function() {
                    mobileHeader.classList.remove('shadow');
                }, 1800);
            }
<?php

                    }

                    if (get_theme_mod('sticky_desktop') === 'site-navigation' || get_theme_mod('sticky_desktop') === 'masthead-wrapper') {

?>
            var desktopHeader = document.getElementById('<?php echo get_theme_mod('sticky_desktop'); ?>');
            if (document.body.clientWidth >= <?php echo ($mobile_breakpoint + 1); ?> && !desktopHeader.classList.contains('shadow')) {
                desktopHeader.classList.add('shadow');
                setTimeout(function() {
                    desktopHeader.classList.remove('shadow');
                }, 1800);
            }
<?php

                    }

?>

        });
    }());
</script>
<?php

                }

                if (get_theme_mod('sticky_mobile') === 'button' || get_theme_mod('sticky_desktop') === 'button') {

                    if (get_theme_mod('sticky_mobile') === 'button') { $width_condition = 'document.body.clientWidth < ' . ($mobile_breakpoint + 1); }

                    if (get_theme_mod('sticky_desktop') === 'button') { $width_condition = 'document.body.clientWidth >= 481'; }

                    if (get_theme_mod('sticky_mobile') === 'button' && get_theme_mod('sticky_desktop') === 'button') { $width_condition = '1 == 1'; }

?>
<script type="text/javascript">
    (function () {
        window.addEventListener('scroll', function() {
            var navToggle = document.getElementsByClassName('menu-button-container')[0];
            if (<?php echo $width_condition; ?>) {
                var siteHeaderHeight = document.getElementById('masthead').clientHeight;
                var adminBar = document.getElementById('wpadminbar');
                if (adminBar !== null && document.body.clientWidth <= 600) { siteHeaderHeight += adminBar.clientHeight; }
                if ((window.pageYOffset || (document.documentElement || document.body.parentNode || document.body).scrollTop) > siteHeaderHeight) {
                    if (!navToggle.classList.contains('sticky')) {
                        document.getElementById('masthead').style.height = siteHeaderHeight + 'px';
                        navToggle.classList.add('sticky');
                        document.body.classList.add('sticky-button');
                        if (!navToggle.classList.contains('shadow')) {
                            navToggle.classList.add('shadow');
                            setTimeout(function() {
                                navToggle.classList.remove('shadow');
                            }, 600);
                        }
                    }
                    if (document.body.clientWidth >= 481 && document.body.classList.contains('primary-navigation-open')) {
                        document.body.classList.remove('primary-navigation-open');
                        document.body.classList.remove('lock-scrolling');
                        twentytwentyoneToggleAriaExpanded(document.getElementById('primary-mobile-menu'));
                    }
                } else {
                    if (navToggle.classList.contains('sticky')) {
                        navToggle.classList.remove('sticky');
                    }
                    if (document.body.classList.contains('sticky-button')) {
                        document.body.classList.remove('sticky-button');
                    }
                    if (document.body.clientWidth >= 481 && document.body.classList.contains('primary-navigation-open')) {
                        document.body.classList.remove('primary-navigation-open');
                        document.body.classList.remove('lock-scrolling');
                        twentytwentyoneToggleAriaExpanded(document.getElementById('primary-mobile-menu'));
                    }
                }
            } else {
                if (navToggle.classList.contains('sticky')) {
                    navToggle.classList.remove('sticky');
                }
                if (document.body.classList.contains('sticky-button')) {
                    document.body.classList.remove('sticky-button');
                }
                if (document.body.classList.contains('primary-navigation-open')) {
                    document.body.classList.remove('primary-navigation-open');
                    document.body.classList.remove('lock-scrolling');
                    twentytwentyoneToggleAriaExpanded(document.getElementById('primary-mobile-menu'));
                }
            }
        });
    }());
</script>
<?php

                }

                if (twenty_twenty_one_can_show_post_thumbnail() && is_singular() && get_theme_mod('featured_header_image')) {

?>
<script type="text/javascript">
    (function() {
        document.querySelector('#masthead-wrapper').style.backgroundImage = 'url("' + document.querySelector('.post-thumbnail .wp-post-image').src + '")';
    })();
</script>
<?php

                }

                if (get_theme_mod('primary_nav_search')) {

?>
<li id="menu-item-search" class="menu-item menu-item-type-search menu-item-object-search menu-item-search">
    <?php echo twenty_twenty_one_get_icon_svg( 'ui', 'search' ); ?>
</li>
<div id="mobile-item-search" class="menu-item menu-item-type-search menu-item-object-search menu-item-search">
    <?php echo twenty_twenty_one_get_icon_svg( 'ui', 'search' ); ?>
</div>
<div id="search-modal">
	<div id="search-modal-inner">
        <?php get_search_form(); ?>
		<button id="close-search-toggle">
				<?php echo twenty_twenty_one_get_icon_svg( 'ui', 'close' ); ?>
		</button>
	</div>
    <div id="search-modal-excess"></div>
</div>
<script type="text/javascript">
    (function () {
        document.querySelector('#primary-menu-list').appendChild(document.querySelector('#menu-item-search'));
        document.querySelector('.menu-button-container').appendChild(document.querySelector('#mobile-item-search'));
        Array.prototype.forEach.call(document.querySelectorAll('#menu-item-search, #mobile-item-search, #close-search-toggle, #search-modal-excess'), function(searchToggle) {
            searchToggle.addEventListener('click', function(buttonEvent) {
                buttonEvent.preventDefault();
                if (document.querySelector('#search-modal').classList.contains('show-modal')) {
                    document.querySelector('#search-modal').classList.remove('show-modal');
                } else {
                    document.querySelector('#search-modal').classList.add('show-modal');
                }
            },false);
        });
    }());
</script>
<?php

                }

                if (get_theme_mod('content_background_color') && is_singular()) {

?>
<script type="text/javascript">
    (function () {
    	var entryContent = document.querySelector('.entry-content')
    	entryContentWrapper = document.createElement('div')
    	entryContentWrapperInnerContainer = document.createElement('div');
        entryContentWrapper.className = 'entry-content';
        entryContentWrapperInnerContainer.className = 'entry-content-wrapper wp-block-group has-background';
        entryContent.parentNode.insertBefore(entryContentWrapper, entryContent);
        entryContentWrapper.appendChild(entryContentWrapperInnerContainer);
        entryContentWrapperInnerContainer.appendChild(entryContent);
        entryContent.className = 'wp-block-group__inner-container';
    }());
</script>
<?php

                }

                $taxonomies = get_theme_mod('archive_featured_images');

                if ($taxonomies && is_array($taxonomies)) {

                    $show_archive_featured_image = false;

                    foreach ($taxonomies as $taxonomy) {

                        if (is_tax($taxonomy) || ($taxonomy == 'category' && is_category()) || ($taxonomy == 'post_tag' && is_tag())) {

                            $show_archive_featured_image = true;

                        }

                    }

                    if ($show_archive_featured_image) {

                    	$post_thumbnail_id = get_term_meta(get_queried_object_id(), '_thumbnail_id', true);

                    }

                    if (!get_theme_mod('hide_featured_images') && $show_archive_featured_image) {

                        if ($post_thumbnail_id) {

?>
<figure class="post-thumbnail archive-thumbnail">
<?php

                            $size = apply_filters('post_thumbnail_size', 'post-thumbnail', 0);
                            do_action('begin_fetch_post_thumbnail_html', 0, $post_thumbnail_id, 'post-thumbnail');
                            $html = wp_get_attachment_image($post_thumbnail_id, 'post-thumbnail', false, array('loading' => false));
                            do_action('end_fetch_post_thumbnail_html', 0, $post_thumbnail_id, 'post-thumbnail');
                            echo apply_filters('post_thumbnail_html', $html, 0, $post_thumbnail_id, 'post-thumbnail', array('loading' => false));

	?>
	<?php if (wp_get_attachment_caption($post_thumbnail_id)) : ?>
		<figcaption class="wp-caption-text"><?php echo wp_kses_post(wp_get_attachment_caption($post_thumbnail_id)); ?></figcaption>
	<?php endif; ?>
</figure><!-- .post-thumbnail -->
<script type="text/javascript">
    (function() {
        document.getElementsByClassName('page-header')[0].appendChild(document.getElementsByClassName('archive-thumbnail')[0]);
    })();
</script>
<?php

                        }

                    }

                    if (get_theme_mod('featured_header_image') && $show_archive_featured_image) {

?>
<script type="text/javascript">
    (function() {
        document.querySelector('#masthead-wrapper').style.backgroundImage = 'url("<?php echo wp_get_attachment_image_src($post_thumbnail_id, 'post-thumbnail')[0]; ?>")';
    })();
</script>
<?php

                    }

                    if (get_theme_mod('featured_background_image') && $show_archive_featured_image) {

?>
<script type="text/javascript">
    (function() {
        document.body.style.backgroundImage = 'url("<?php echo wp_get_attachment_image_src($post_thumbnail_id, 'post-thumbnail')[0]; ?>")';
    })();
</script>
<?php

                    }

                }

                if (get_theme_mod('parallax_cover_block')) {

                    $parallax_amount = 0.5;

?>
<script type="text/javascript">
    window.addEventListener('scroll', function() {
        if (window.matchMedia('(min-width: 482px)').matches) {
            Array.prototype.forEach.call(document.getElementsByClassName('wp-block-cover'), function(wpBlockCover) {
                var $images = wpBlockCover.getElementsByTagName('img'), $image;
                if ($images) {
                    $image = $images[0];
                    if ((pageYOffset + window.innerHeight > wpBlockCover.offsetTop) && (pageYOffset < wpBlockCover.offsetTop + wpBlockCover.offsetHeight)) {
                        $image.style.transform = 'scale(<?php echo $parallax_amount + 1; ?>) translateY(' + (<?php echo $parallax_amount / ($parallax_amount + 1) * 50; ?> - (((pageYOffset - wpBlockCover.offsetTop + window.innerHeight) / (wpBlockCover.offsetTop + wpBlockCover.offsetHeight - wpBlockCover.offsetTop + window.innerHeight)) * <?php echo $parallax_amount / ($parallax_amount + 1) * 100; ?>)) + '%)';
                    }
                }
            });
        }
    });
</script>
<?php

                }

                if (get_theme_mod('footer_widget_area_background_color')) {

?>
<script type="text/javascript">
    (function () {
    	var siteWidgetArea = document.getElementsByClassName('widget-area')[0];
        var widgetAreaWrapper = document.createElement('div');
        widgetAreaWrapper.id = 'widget-area-wrapper';
        siteWidgetArea.parentNode.insertBefore(widgetAreaWrapper, siteWidgetArea);
        widgetAreaWrapper.appendChild(siteWidgetArea);
    }());
</script>
<?php

                }

                if (get_theme_mod('replace_site_title_logo')) {

?>
<script type="text/javascript">
    (function() {
        document.getElementsByClassName('site-name')[0].innerHTML = '<?php echo addslashes(get_theme_mod('replace_site_title_logo')); ?>';
    })();
</script>
<?php

                }

                if (get_theme_mod('replace_powered_by_wordpress')) {

?>
<script type="text/javascript">
    (function() {
        document.getElementsByClassName('powered-by')[0].innerHTML = '<?php echo addslashes(get_theme_mod('replace_powered_by_wordpress')); ?>';
    })();
</script>
<?php

                }

                if (self::oftto_is_dark_mode_enabled() && get_theme_mod('dark_mode_on')) {

?>
<script type="text/javascript">
    (function() {
        if (!document.getElementsByClassName('is-dark-theme').length) {
    	    document.getElementById('dark-mode-toggler').click();
        }
    })();
</script>
<?php

                }

                $mod = get_theme_mod('dark_mode_logo');

                if ($mod && self::oftto_is_dark_mode_enabled()) {

                    $image = wp_get_attachment_image_src($mod, 'full', false);
                    list($src, $width, $height) = $image;
                    $image_meta = wp_get_attachment_metadata($mod);
 
                    if (is_array($image_meta)) {

                        $size_array = array(absint($width), absint($height));
                        $srcset = wp_calculate_image_srcset($size_array, $src, $image_meta, $mod);
 
                    }

?>
<script type="text/javascript">
    (function() {
        function toggleDarkLogo() {
            Array.prototype.forEach.call(document.getElementsByClassName('custom-logo'), function(customLogo) {
                var darkLogoSrc = customLogo.src;
                var darkLogoSrcset = customLogo.srcset;
                customLogo.src = customLogo.dataset.darklogosrc;
                customLogo.srcset = customLogo.dataset.darklogosrcset;
                customLogo.dataset.darklogosrc = darkLogoSrc;
                customLogo.dataset.darklogosrcset = darkLogoSrcset;
            });
        }
        Array.prototype.forEach.call(document.getElementsByClassName('custom-logo'), function(customLogo) {
            customLogo.dataset.darklogosrc = <?php echo json_encode((wp_get_attachment_image_src($mod, 'full') ? wp_get_attachment_image_src($mod, 'full')[0] : '')); ?>;
            customLogo.dataset.darklogosrcset = <?php echo json_encode(($srcset ? $srcset : '')); ?>;
        });
        document.addEventListener('DOMContentLoaded', function() {
            if (twentytwentyoneIsDarkMode()) {
                toggleDarkLogo();
            }
            document.getElementById('dark-mode-toggler').addEventListener('click', toggleDarkLogo);
        });
    })();
</script>
<?php

                }

            }

        }

        public function oftto_widgets_init() {

            register_sidebar(array(
                'name'          => esc_html__('Header', 'options-for-twenty-twenty-one'),
                'id'            => 'sidebar-3',
                'description'   => esc_html__('Add widgets here to appear in your header.', 'options-for-twenty-twenty-one'),
                'before_title'  => '<h2 class="widget-title">',
                'after_title'   => '</h2>',
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget'  => '</section>'
            ));

        }

        public function oftto_remove_archive_title_prefix($prefix) {
 
            if ($prefix === 'Category:' || $prefix === 'Tag:') {

                $prefix = '';

            }

            return $prefix;

        }

        function oftto_theme_options_metabox_setup() {

            add_action('add_meta_boxes', array($this, 'oftto_add_theme_options_metabox'));

            if (ofttoPremium::request_permission() == true) {

                add_action('save_post', array($this, 'oftto_save_theme_options_meta'), 10, 2);

            }

        }

        function oftto_add_theme_options_metabox() {

            add_meta_box('oftto_meta_box', __('Theme Options', 'options-for-twenty-twenty-one'), array($this, 'oftto_render_theme_options_metabox'), array('post', 'page', 'jetpack-portfolio'), 'side');

        }

        function oftto_render_theme_options_metabox($post) {

            if (!get_option(ofttoCommon::$plugin_prefix . '_purchased')) {

                echo '<p><strong>' . __('To keep using premium options', ofttoCommon::$plugin_text_domain) . '</strong>' . ' ' . ofttoCommon::control_upgrade_text() . '.</p>';

            }

            wp_nonce_field('options-for-twenty-twenty-one', 'oftto-meta-nonce');

            if (ofttoPremium::request_permission() == true) {

?>
<input type="checkbox" name="oftto-hide-site-header" id="oftto-hide-site-header" value="1" <?php checked(get_post_meta($post->ID, 'oftto_hide_site_header', true), '1' ); ?> />
<label for="oftto-hide-site-header"><?php echo ((get_theme_mod('hide_site_header') ? __('Show Site Header', 'options-for-twenty-twenty-one') : __('Hide Site Header', 'options-for-twenty-twenty-one'))); ?></label>
<br />
<input type="checkbox" name="oftto-absolute-site-header" id="oftto-absolute-site-header" value="1" <?php checked(get_post_meta($post->ID, 'oftto_absolute_site_header', true), '1' ); ?> />
<label for="oftto-absolute-site-header"><?php echo ((get_theme_mod('absolute_site_header') ? __('Don\'t Show Content Behind Site Header', 'options-for-twenty-twenty-one') : __('Show Content Behind Site Header', 'options-for-twenty-twenty-one'))); ?></label>
<br />
<input type="checkbox" name="oftto-hide-header" id="oftto-hide-header" value="1" <?php checked(get_post_meta($post->ID, 'oftto_hide_header', true), '1' ); ?> />
<label for="oftto-hide-header"><?php echo ((get_theme_mod('hide_page_headers') ? __('Show Post / Page Header', 'options-for-twenty-twenty-one') : __('Hide Post / Page Header', 'options-for-twenty-twenty-one'))); ?></label>
<br />
<input type="checkbox" name="oftto-hide-header-title" id="oftto-hide-header-title" value="1" <?php checked(get_post_meta($post->ID, 'oftto_hide_header_title', true), '1' ); ?> />
<label for="oftto-hide-header-title"><?php echo ((get_theme_mod('hide_page_titles') ? __('Show Title', 'options-for-twenty-twenty-one') : __('Hide Title', 'options-for-twenty-twenty-one'))); ?></label>
<br />
<input type="checkbox" name="oftto-hide-featured-image" id="oftto-hide-featured-image" value="1" <?php checked(get_post_meta($post->ID, 'oftto_hide_featured_image', true), '1' ); ?> />
<label for="oftto-hide-featured-image"><?php echo ((get_theme_mod('hide_featured_images') ? __('Show Featured Image', 'options-for-twenty-twenty-one') : __('Hide Featured Image', 'options-for-twenty-twenty-one'))); ?></label>
<br />
<input type="checkbox" name="oftto-show-sidebar" id="oftto-show-sidebar" value="1" <?php checked(get_post_meta($post->ID, 'oftto_show_sidebar', true), '1' ); ?> />
<label for="oftto-show-sidebar"><?php _e('Show Sidebar', 'options-for-twenty-twenty-one'); ?></label>
<br />
<input type="checkbox" name="oftto-hide-sidebar" id="oftto-hide-sidebar" value="1" <?php checked(get_post_meta($post->ID, 'oftto_hide_sidebar', true), '1' ); ?> />
<label for="oftto-hide-sidebar"><?php _e('Hide Sidebar (this will override the above setting)', 'options-for-twenty-twenty-one'); ?></label>
<br />
<input type="checkbox" name="oftto-hide-widget-area" id="oftto-hide-widget-area" value="1" <?php checked(get_post_meta($post->ID, 'oftto_hide_widget_area', true), '1' ); ?> />
<label for="oftto-hide-widget-area"><?php echo __('Hide Widget Area', 'options-for-twenty-twenty-one'); ?></label>
<br />
<input type="checkbox" name="oftto-hide-footer" id="oftto-hide-footer" value="1" <?php checked(get_post_meta($post->ID, 'oftto_hide_footer', true), '1' ); ?> />
<label for="oftto-hide-footer"><?php echo __('Hide Footer', 'options-for-twenty-twenty-one'); ?></label>
<?php

            } else {

?>

<p><?php echo $upgrade_link; ?> <?php _e('to hide the site header, to show content behind the site header, to hide the post / page header, to hide the header title or featured image or to show / hide the sidebar.', 'options-for-twenty-twenty-one'); ?></p>

<?php
            }

        }

        function oftto_save_theme_options_meta($post_id, $post) {

            if (!isset( $_POST['oftto-meta-nonce'] ) || !wp_verify_nonce($_POST['oftto-meta-nonce'], 'options-for-twenty-twenty-one')) {

                return;

            }

            $post_type = get_post_type_object($post->post_type);

            if (!current_user_can($post_type->cap->edit_post, $post_id)) {

                return;

            }

            if (isset($_POST['oftto-hide-site-header']) && $_POST['oftto-hide-site-header'] == '1') {

                update_post_meta($post_id, 'oftto_hide_site_header', 1);

            } else {

                delete_post_meta($post_id, 'oftto_hide_site_header');

            }

            if (isset($_POST['oftto-absolute-site-header']) && $_POST['oftto-absolute-site-header'] == '1') {

                update_post_meta($post_id, 'oftto_absolute_site_header', 1);

            } else {

                delete_post_meta($post_id, 'oftto_absolute_site_header');

            }

            if (isset($_POST['oftto-hide-header']) && $_POST['oftto-hide-header'] == '1') {

                update_post_meta($post_id, 'oftto_hide_header', 1);

            } else {

                delete_post_meta($post_id, 'oftto_hide_header');

            }

            if (isset($_POST['oftto-hide-header-title']) && $_POST['oftto-hide-header-title'] == '1') {

                update_post_meta($post_id, 'oftto_hide_header_title', 1);

            } else {

                delete_post_meta($post_id, 'oftto_hide_header_title');

            }

            if (isset($_POST['oftto-hide-featured-image']) && $_POST['oftto-hide-featured-image'] == '1') {

                update_post_meta($post_id, 'oftto_hide_featured_image', 1);

            } else {

                delete_post_meta($post_id, 'oftto_hide_featured_image');

            }

            if (isset($_POST['oftto-show-sidebar']) && $_POST['oftto-show-sidebar'] == '1') {

                update_post_meta($post_id, 'oftto_show_sidebar', 1);

            } else {

                delete_post_meta($post_id, 'oftto_show_sidebar');

            }

            if (isset($_POST['oftto-hide-sidebar']) && $_POST['oftto-hide-sidebar'] == '1') {

                update_post_meta($post_id, 'oftto_hide_sidebar', 1);

            } else {

                delete_post_meta($post_id, 'oftto_hide_sidebar');

            }

            if (isset($_POST['oftto-hide-widget-area']) && $_POST['oftto-hide-widget-area'] == '1') {

                update_post_meta($post_id, 'oftto_hide_widget_area', 1);

            } else {

                delete_post_meta($post_id, 'oftto_hide_widget_area');

            }

            if (isset($_POST['oftto-hide-footer']) && $_POST['oftto-hide-footer'] == '1') {

                update_post_meta($post_id, 'oftto_hide_footer', 1);

            } else {

                delete_post_meta($post_id, 'oftto_hide_footer');

            }

        }

        public function oftto_inject_ui_icons($icons) {

		    $icons['search'] = '<svg xmlns="http://www.w3.org/2000/svg" width="23" height="23" viewBox="0 0 23 23">
		<path d="M38.710696,48.0601792 L43,52.3494831 L41.3494831,54 L37.0601792,49.710696 C35.2632422,51.1481185 32.9839107,52.0076499 30.5038249,52.0076499 C24.7027226,52.0076499 20,47.3049272 20,41.5038249 C20,35.7027226 24.7027226,31 30.5038249,31 C36.3049272,31 41.0076499,35.7027226 41.0076499,41.5038249 C41.0076499,43.9839107 40.1481185,46.2632422 38.710696,48.0601792 Z M36.3875844,47.1716785 C37.8030221,45.7026647 38.6734666,43.7048964 38.6734666,41.5038249 C38.6734666,36.9918565 35.0157934,33.3341833 30.5038249,33.3341833 C25.9918565,33.3341833 22.3341833,36.9918565 22.3341833,41.5038249 C22.3341833,46.0157934 25.9918565,49.6734666 30.5038249,49.6734666 C32.7048964,49.6734666 34.7026647,48.8030221 36.1716785,47.3875844 C36.2023931,47.347638 36.2360451,47.3092237 36.2726343,47.2726343 C36.3092237,47.2360451 36.347638,47.2023931 36.3875844,47.1716785 Z" transform="translate(-20 -31)"/>
		</svg>';

            return $icons;

        }

        public function oftto_extract_social_icons($icons) {

		    $icons['linkedin'] = '<svg width="24" height="24" viewBox="0 0 128.03 127.93" version="1.1" xmlns="http://www.w3.org/2000/svg"><path d="M63.99,0.04c18.17,0,36.34,0.05,54.51-0.04c4.84-0.02,8.76,3.44,9.41,7.7c0.07,0.47,0.11,0.95,0.11,1.42
	c0.01,36.57,0.01,73.14,0,109.71c0,4.85-3.86,8.86-8.69,9.07c-0.32,0.01-0.64,0.01-0.96,0.01c-36.26,0-72.52,0-108.79,0
	c-4.55,0-7.99-2.44-9.19-6.57c-0.25-0.87-0.38-1.8-0.39-2.7C0,82.21,0,45.75,0,9.3c0-5.19,3.91-9.19,9.11-9.25
	C13.51,0,17.9,0.04,22.29,0.04C36.19,0.04,50.09,0.04,63.99,0.04z M68.27,55.82c0-2.19-0.05-4.39,0.02-6.58
	c0.04-1.11-0.34-1.42-1.44-1.41c-5.19,0.05-10.38,0.02-15.57,0.02c-1.59,0-1.6,0-1.6,1.57c0,19.44,0.01,38.88-0.03,58.32
	c0,1.23,0.38,1.57,1.57,1.56c5.39-0.05,10.78-0.02,16.17-0.02c1.6,0,1.6-0.01,1.6-1.57c0-9.78-0.03-19.56,0.02-29.34
	c0.01-2.02,0.14-4.07,0.5-6.06c0.74-4.14,2.65-7.48,7.07-8.58c1.33-0.33,2.76-0.39,4.14-0.38c4.56,0.06,7.42,2.19,8.42,6.62
	c0.56,2.46,0.77,5.04,0.8,7.57c0.09,10.06,0.05,20.12,0.01,30.18c0,1.2,0.37,1.59,1.58,1.58c5.39-0.05,10.78-0.05,16.17,0
	c1.16,0.01,1.58-0.28,1.57-1.53c-0.05-11.66,0.09-23.32-0.1-34.97c-0.06-3.87-0.59-7.8-1.45-11.57c-1.56-6.79-5.51-11.75-12.45-13.7
	c-2.39-0.67-4.93-0.83-7.41-1.13c-4.2-0.49-8.16,0.36-11.87,2.35C72.86,50.45,70.37,52.87,68.27,55.82z M18.76,78.53
	c0,9.78,0.01,19.55-0.02,29.33c0,0.99,0.21,1.44,1.3,1.43c5.59-0.04,11.18-0.04,16.77,0c1.01,0.01,1.29-0.38,1.29-1.35
	c-0.02-19.59-0.02-39.19,0-58.78c0-1.08-0.37-1.34-1.39-1.33c-5.51,0.04-11.02,0.05-16.53-0.01c-1.19-0.01-1.45,0.37-1.45,1.5
	C18.78,59.05,18.76,68.79,18.76,78.53z M28.4,39.64c6.18,0,11.13-4.9,11.14-11.02c0.01-6.21-4.94-11.19-11.11-11.2
	c-6.21,0-11.12,4.93-11.12,11.16C17.32,34.74,22.23,39.64,28.4,39.64z"></path></svg>';
            $icons['xing'] = '<svg width="24" height="24" viewBox="0 0 24 24" version="1.1" xmlns="http://www.w3.org/2000/svg"><path d="M24,1.4C23.9,0.6,23.1,0,22.2,0C18.8,0,15.4,0,12,0C9.4,0,6.8,0,4.2,0C3.4,0,2.5,0,1.7,0C0.7,0,0,0.8,0,1.7
	c0,6.8,0,13.7,0,20.5c0,0.2,0,0.3,0.1,0.5C0.3,23.5,0.9,24,1.8,24c6.8,0,13.6,0,20.4,0c0.1,0,0.1,0,0.2,0c0.9,0,1.6-0.8,1.6-1.7
	c0-6.9,0-13.7,0-20.6C24,1.6,24,1.5,24,1.4z M6.7,15.7H4.1c-0.1,0-0.3-0.1-0.4-0.1c-0.1-0.1-0.1-0.3,0-0.4l2.8-5L4.7,7
	c-0.1-0.1-0.1-0.3,0-0.4c0.1-0.1,0.2-0.1,0.4-0.1h2.7c0.4,0,0.6,0.3,0.7,0.5l1.9,3.2c-0.1,0.1-2.9,5.1-2.9,5.1
	C7.3,15.4,7.1,15.7,6.7,15.7z M19.3,3.3l-5.9,10.5l3.7,6.9c0.1,0.1,0.1,0.3,0,0.4c-0.1,0.1-0.2,0.1-0.4,0.1h-2.7
	c-0.4,0-0.6-0.3-0.7-0.5l-3.8-6.9c0.2-0.3,6-10.5,6-10.5c0.1-0.3,0.4-0.5,0.7-0.5H19c0.1,0,0.3,0.1,0.4,0.1
	C19.4,3,19.4,3.2,19.3,3.3z"></path></svg>';
            $icons['telegram'] = '<svg width="24" height="24" viewBox="0 0 543 450" version="1.1" xmlns="http://www.w3.org/2000/svg"><path d="M37.3,193.7c145.8-63.5,243-105.4,291.6-125.6C467.8,10.4,496.6,0.3,515.4,0
	c4.1-0.1,13.4,1,19.4,5.8c5.1,4.1,6.5,9.6,7.1,13.5s1.5,12.8,0.8,19.7c-7.5,79.1-40.1,270.9-56.6,359.5c-7,37.5-20.8,50-34.2,51.3
	c-29,2.7-51.1-19.2-79.2-37.6c-44-28.8-68.9-46.8-111.6-75c-49.4-32.5-17.4-50.4,10.8-79.6c7.4-7.6,135.3-124,137.8-134.6
	c0.3-1.3,0.6-6.2-2.3-8.8s-7.2-1.7-10.4-1c-4.4,1-74.7,47.5-210.9,139.4c-20,13.7-38,20.4-54.2,20c-17.9-0.4-52.2-10.1-77.7-18.4
	C22.9,244-2,238.6,0.1,221.3C1.3,212.3,13.7,203.1,37.3,193.7z"></path></svg>';
            $icons['tiktok'] = '<svg width="24" height="24" viewBox="0 0 12.9 15" version="1.1" xmlns="http://www.w3.org/2000/svg"><path d="M9.2,10.1V4.6c1.1,0.8,2.4,1.2,3.8,1.2V3.7c-0.8-0.2-1.5-0.6-2-1.2C10,1.9,9.4,1,9.2,0h-2l0,10.8c0,1.2-1,2.2-2.3,2.2
	c-0.8,0-1.4-0.4-1.8-0.9c-0.7-0.4-1.2-1.1-1.2-2c0-1.3,1-2.3,2.3-2.3c0.2,0,0.5,0,0.7,0.1V5.8C2.2,5.8,0,8,0,10.8
	c0,1.3,0.5,2.5,1.3,3.4C2.1,14.7,3.1,15,4.2,15C6.9,15,9.2,12.8,9.2,10.1"></path></svg>';
            $icons['whatsapp'] = '<svg width="24" height="24" viewBox="0 0 36.7 37" version="1.1" xmlns="http://www.w3.org/2000/svg"><path d="M31.4,5.4C28,1.9,23.3,0,18.5,0C8.3,0,0.1,8.3,0.2,18.4c0,3.2,0.9,6.3,2.4,9.1L0,37l9.7-2.5c2.7,1.5,5.7,2.2,8.7,2.2l0,0
	c10.1,0,18.3-8.3,18.3-18.4C36.7,13.4,34.8,8.8,31.4,5.4z M18.5,33.6L18.5,33.6c-2.7,0-5.4-0.7-7.7-2.1l-0.6-0.3l-5.8,1.5L5.9,27
	l-0.4-0.6C1.1,19.3,3.2,9.9,10.4,5.5s16.5-2.3,20.9,4.9s2.3,16.5-4.9,20.9C24.1,32.8,21.3,33.6,18.5,33.6z M27.3,22.5L26.2,22
	c0,0-1.6-0.7-2.6-1.2c-0.1,0-0.2-0.1-0.3-0.1c-0.3,0-0.5,0.1-0.7,0.2l0,0c0,0-0.1,0.1-1.5,1.7c-0.1,0.2-0.3,0.3-0.5,0.3h-0.1
	c-0.1,0-0.3-0.1-0.4-0.2l-0.5-0.2l0,0c-1.1-0.5-2.1-1.1-2.9-1.9c-0.2-0.2-0.5-0.4-0.7-0.6c-0.7-0.7-1.4-1.5-1.9-2.4L14,17.4
	c-0.1-0.1-0.1-0.2-0.2-0.4c0-0.2,0-0.4,0.1-0.5c0,0,0.4-0.5,0.7-0.8c0.2-0.2,0.3-0.5,0.5-0.7c0.2-0.3,0.3-0.7,0.2-1
	c-0.1-0.5-1.3-3.2-1.6-3.8c-0.2-0.3-0.4-0.4-0.7-0.5h-0.3c-0.2,0-0.5,0-0.8,0c-0.2,0-0.4,0.1-0.6,0.1l-0.1,0.1
	c-0.2,0.1-0.4,0.3-0.6,0.4c-0.2,0.2-0.3,0.4-0.5,0.6C9.4,11.8,9,12.9,9,14l0,0c0,0.8,0.2,1.6,0.5,2.3l0.1,0.3
	c0.9,1.9,2.1,3.6,3.7,5.1l0.4,0.4c0.3,0.3,0.6,0.5,0.8,0.8c2.1,1.8,4.5,3.1,7.2,3.8c0.3,0.1,0.7,0.1,1,0.2l0,0c0.3,0,0.7,0,1,0
	c0.5,0,1.1-0.2,1.5-0.4c0.3-0.2,0.5-0.2,0.7-0.4l0.2-0.2c0.2-0.2,0.4-0.3,0.6-0.5s0.4-0.4,0.5-0.6c0.2-0.4,0.3-0.9,0.4-1.4
	c0-0.2,0-0.5,0-0.7C27.6,22.7,27.5,22.6,27.3,22.5z"/></svg>';

            if (ofttoPremium::request_permission() && get_theme_mod('colored_social_links_menu') && !isset(self::$social_icons)) {

                self::$social_icons = $icons;

            }

            return $icons;

        }

        public function oftto_extract_social_icons_map($icon_map) {

            $icon_map['telegram'] = array(
                'telegram.org',
                't.me'
            );
            $icon_map['whatsapp'] = array(
                'whatsapp.com',
                'wa.me'
            );

            if (ofttoPremium::request_permission() && get_theme_mod('colored_social_links_menu') && !isset(self::$social_icons_map)) {

                self::$social_icons_map = $icon_map;

            }

            return $icon_map;

        }

        public function oftto_nav_menu_social_icons_class_inject($item_output, $item, $depth, $args) {

            if (ofttoPremium::request_permission() && get_theme_mod('colored_social_links_menu')) {

        		if (isset(self::$social_icons) && isset(self::$social_icons_map) && !isset(self::$social_icons_regex_map)) {

        			self::$social_icons_regex_map = array();

        			foreach (array_keys(self::$social_icons ) as $icon) {

        				$domains          = array_key_exists($icon, self::$social_icons_map) ? self::$social_icons_map[$icon] : array(sprintf('%s.com', $icon));
        				$domains          = array_map('trim', $domains);
        				$domains          = array_map('preg_quote', $domains);
        				self::$social_icons_regex_map[$icon] = sprintf('/(%s)/i', implode('|', $domains));

        			}

        		}

                if (isset(self::$social_icons) && 'footer' === $args->theme_location) {

            		foreach (self::$social_icons_regex_map as $icon => $regex) {

            			if (preg_match($regex, $item->url)) {

            				$item_output = str_replace('"><svg class="', '" class="social-color-' . $icon . '"><svg class="', $item_output);

            			}

            		}

            	}

            }

        	return $item_output;

        }

        public function oftto_archive_featured_images () {

            if (ofttoPremium::request_permission()) {

                $taxonomies = get_theme_mod('archive_featured_images');

                if ($taxonomies && is_array($taxonomies)) {

                    if (is_admin()) {

                        foreach ($taxonomies as $taxonomy) {

                            add_action($taxonomy . '_edit_form_fields', array($this, 'oftto_taxonomy_meta_fields'), 10, 2);
                            add_action('edited_' . $taxonomy, array($this, 'oftto_save_taxonomy_meta'), 10, 2);

                        }

                        add_action('admin_enqueue_scripts', array($this, 'oftto_admin_enqueue_scripts'));
                        add_action('wp_ajax_oftto_get_attachment_url', array($this, 'oftto_ajax_get_attachment_url'));

                    }

                }

            }

        }

        public function oftto_taxonomy_meta_fields($tag, $taxonomy) {

            wp_nonce_field('oftto-meta', 'oftto-meta-nonce');

?>
<table class="form-table" role="presentation">
    <tr class="form-field term-featured-image-wrap">
        <th scope="row"><label for="_thumbnail_id"><?php _e('Featured Image', 'options-for-twenty-twenty-one'); ?></label></th>
        <td>
<?php

        $image_id = absint(get_term_meta($tag->term_id, '_thumbnail_id', true));

        if ($image_id > 0) {

?>
            <img id="_thumbnail_id_preview_image" src="<?php echo wp_get_attachment_image_src($image_id, 'medium')[0]; ?>" />
<?php

        } else {

?>
            <img id="_thumbnail_id_preview_image" />
<?php

        }
?>
            <br />
            <input id="_thumbnail_id" name="_thumbnail_id" type="hidden" value="<?php if ($image_id) { echo esc_html($image_id); } ?>" />
            <input type="button" class="button-primary" value="<?php esc_attr_e('Select Image', 'options-for-twenty-twenty-one' ); ?>" id="_thumbnail_id_media_manager" data-button="<?php echo wp_create_nonce('oftto-meta'); ?>" />
            <input type="button" class="button" value="<?php esc_attr_e('Clear', 'options-for-twenty-twenty-one' ); ?>" onclick="jQuery('input#_thumbnail_id').removeAttr('value'); jQuery('img#_thumbnail_id_preview_image').removeAttr('src').replaceWith(jQuery('img#_thumbnail_id_preview_image').clone());" />
        </td>
    </tr>
</table>

<script type="text/javascript">
jQuery(document).ready( function() {
    jQuery('input#_thumbnail_id_media_manager').click(function(e) {
        e.preventDefault();
        var image_frame;
        if(image_frame){
            image_frame.open();
        }
        image_frame = wp.media({
            title: '<?php _e('Select Media', 'options-for-twenty-twenty-one'); ?>',
            multiple : false,
            library : {
                type : 'image',
            }
        });
        image_frame.on('close',function() {
            var selection =  image_frame.state().get('selection');
            var gallery_ids = [];
            var my_index = 0;
            selection.each(function(attachment) {
                gallery_ids[my_index] = attachment.id;
                my_index++;
            });
            var ids = gallery_ids.join(",");
            jQuery('input#_thumbnail_id').val(ids);
            ofttoRefreshImage(ids, '_thumbnail_id');
        });
        image_frame.on('open',function() {
            var selection =  image_frame.state().get('selection');
            ids = jQuery('input#_thumbnail_id').val().split(',');
            ids.forEach(function(id) {
                attachment = wp.media.attachment(id);
                attachment.fetch();
                selection.add( attachment ? [ attachment ] : [] );
            });
        });
        image_frame.open();
    });
});
function ofttoRefreshImage(the_id, option_type){
    var data = {
        action: 'oftto_get_attachment_url',
        id: the_id,
        _wpnonce: jQuery('input#' + option_type + '_media_manager').attr('data-button')
    };
    jQuery.get(ajaxurl, data, function(response) {
        if(response.success === true) {
            jQuery('#' + option_type + '_preview_image').attr('src', response.data.url);
        }
    });
}
</script>

<?php

        }

        public function oftto_save_taxonomy_meta($term_id, $tt_id) {

            if (!isset($_POST['oftto-meta-nonce']) || !wp_verify_nonce($_POST['oftto-meta-nonce'], 'oftto-meta') || !current_user_can('manage_options')) {

                return;

            }

            if (isset($_POST['_thumbnail_id']) && absint($_POST['_thumbnail_id'])) {

                update_term_meta($term_id, '_thumbnail_id', absint($_POST['_thumbnail_id']));

            } else {

                delete_term_meta($term_id, '_thumbnail_id');

            }

        }

        public function oftto_admin_enqueue_scripts($hook_suffix) {

            if ($hook_suffix != 'term.php') {

                return;

            }

            wp_enqueue_media();

        }

        public function oftto_ajax_get_attachment_url() {

            check_ajax_referer('oftto-meta');

            if (current_user_can('manage_options') && isset($_GET['id']) && absint($_GET['id']) > 0) {

                $data = array(
                    'url' => wp_get_attachment_image_src(absint($_GET['id']), 'medium')[0]
                );

                wp_send_json_success($data);

            } else {

                wp_send_json_error();

            }

        }

        public static function oftto_is_dark_mode_enabled() {

            return (get_theme_mod('respect_user_color_preference') ? true : false);

        }

        public static function oftto_has_masthead_wrapper() {

            return (get_theme_mod('header_background_image') || get_theme_mod('header_background_color') ? true : false);

        }

	}

    if (!class_exists('ofttoPremium')) {

        require_once(dirname(__FILE__) . '/includes/class-oftto-premium.php');

    }

    function options_for_twenty_twenty_one_premium_init() {

        global $options_for_twenty_twenty_one_object;

        if (isset($options_for_twenty_twenty_one_object) && is_object($options_for_twenty_twenty_one_object) && class_exists('ofttoCommon')) {

            if (is_admin()) {

                ofttoPremium::start_trial();

            }

            $options_for_twenty_twenty_one_premium_object = new options_for_twenty_twenty_one_premium_class();

        } elseif (!class_exists('options_for_twenty_twenty_one_class')) {

            add_action('admin_notices', 'ofttoPremium::free_plugin_notice');

        }

    }

    add_action('plugins_loaded', 'options_for_twenty_twenty_one_premium_init');

    if (get_theme_mod('show_updated_date')) {

if ( ! function_exists( 'twenty_twenty_one_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the updated on post-date/time.
	 *
	 * @since Twenty Twenty-One 1.5
	 *
	 * @return void
	 */
	function twenty_twenty_one_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);
		echo '<span class="posted-on">';
		printf(
			/* translators: %s: Updated date. */
			esc_html__( 'Updated %s', 'twentytwentyone' ),
			$time_string // phpcs:ignore WordPress.Security.EscapeOutput
		);
		echo '</span>';
	}
}

    }

}

?>
